<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AbonoActividad;
use App\Models\Abonos;
use App\Models\AbonoWeb;
use App\Models\Caja;
use App\Models\DescuentoEstudiatens;
use App\Models\DeudaBus;
use App\Models\DeudaColegiatura;
use App\Models\DeudaExtra;
use App\Models\DeudaInscripcion;
use App\Models\Estudiante;
use App\Models\Factura;
use App\Models\Grado;
use App\Models\VentaActividad;
use App\Models\VentaBolsa;
use App\Models\VentaBus;
use App\Models\VentaLibros;
use App\Models\VentaUnidormeProfeso;
use App\Models\VentaUniforme;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class AbonosController extends Controller
{

    public function abonoStore(Request $request)
    {

        // dd($request->abonoa);   
        $estudiante = Estudiante::find($request->estudiante_id);

        if ($request->mes !== 'ENERO') {
            if ($this->bloqueoMesAnterior($request) == 0 && $request->abonoa == 'COLEGIATURA') {
                alert()->warning('ALERTA', 'REVISE QUE TENGA PAGO DEL MES ANTERIOR');
                return back();
            }
        }

        $temp_ab = Abonos::where([
            ['abonoa', $request->abonoa],
            ['descripcion', 'like', '%' . $request->mes . '%'],
            ['estudiante_id',  $request->estudiante_id]
        ])->count();

        if ($temp_ab >= 1 && $request->abonoa == 'COLEGIATURA') {
            alert()->warning('ALERTA', 'ESTE PAGO YA HA SIDO ASIGNADO');
            return back();
        }

        if ($request->tipo === 'DEPOSITO' || $request->tipo === 'TRANSFERENCIA') {
            $abono = $this->transferExisit($request);
            if ($abono > 0) {
                return back()->with(['info' => 'boleta, ya registrada', 'color' => 'danger']);
            }
        }

        // PARA obtener datos de una factura previamente creada y asignarla a la nueva
        $dato = DB::table('abonos')
            ->select('*')
            ->where('estudiante_id', $request->estudiante_id)
            ->where('deleted_at', '=', null)
            ->whereDate('created_at', date('Y-m-d'))
            ->first();

        $ab = new Abonos();
        $ab->estudiante_id = $request->estudiante_id;
        $ab->user_id = Auth::user()->id;
        if ($dato) {
            $ab->factura_id = $dato->factura_id;
        } else {
            $ab->factura_id = $this->guardarFactura($request)->id;
        }
        $ab->valor = $request->valor;
        $ab->descripcion = 'MES DE: ' . $request->mes . '<br>' .  $request->descripcion;
        $ab->estado = 'PAGADO';
        $ab->tipo = $request->tipo;
        $ab->banco = $request->banco;
        $ab->boleta = $request->boleta;

        if ($request->tipo === 'VISA') {
            $valor = $request->valor * 0.05;
            $caja = new Caja();
            $caja->valor = $valor;
            $caja->descripcion = 'PAGOS CON TARJETA';
            $caja->operacion = 's';
            $caja->tipo = 'GASTOS ADMINISTRATIVOS';
            $caja->fecha = date('Y-m-d');
            $caja->user_id = Auth::user()->id;
            // dd('Dato Guardado');
            $caja->save();
        }

        // dd($request->tipo);

        if ($request->abonoa === 'COLEGIATURA') {
            // ingrasar deuda COLEGIATURA

            if ($request->valor != $estudiante->colegiatura) {
                alert()->warning('ALERTA', 'SU PAGO DEBE DE SER IGUAL QUE LA COLEGIATURA');
                return back();
            }

            $ab->abonoa = $request->abonoa;
            $this->deudaColegiatura($request->estudiante_id, $request->mes, $request->valor);
        }
        if ($request->abonoa === 'BUS') {
            // ingrasar deuda BUS
            $venta_bus = $this->abonaAexisit('BUS',  $request->estudiante_id, $request->valor);
            if ($venta_bus === 0) return back()->with(['info' => 'no se puede abonar a bus por que no se ha realizadon una venta', 'color' => 'danger']);
            $ab->abonoa = $request->abonoa;
        }
        if ($request->abonoa === 'BOLSA DE UTILES') {
            // ingrasar deuda BOLSA
            $venta = $this->abonaAexisit('BOLSA DE UTILES',  $request->estudiante_id, $request->valor);
            if ($venta === 'NO') return back()->with(['info' => 'no se puede abonar a bolsa por que no se ha realizadon una venta', 'color' => 'danger']);

            if ($venta > 0) return back()->with(['info' => 'no se puede abonar a bolsa por que el abono exede la venta', 'color' => 'danger']);
            $ab->abonoa = $request->abonoa;
        }
        if ($request->abonoa === 'UNIFORME') {
            // ingrasar deuda UNIFORME
            $venta = $this->abonaAexisit('UNIFORME',  $request->estudiante_id, $request->valor);

            if ($venta === 'NO') return back()->with(['info' => 'no se puede abonar a uniforme por que no se ha realizadon una venta', 'color' => 'danger']);
            if ($venta > 0) return back()->with(['info' => 'no se puede abonar a uniforme por que el abono exede la venta', 'color' => 'danger']);
            $ab->abonoa = $request->abonoa;
        }
        if ($request->abonoa === 'INSCRIPCION') {
            // ingrasar deuda INSCRIPCION
            if ($request->valor != $estudiante->inscripcion) {
                alert()->warning('ALERTA', 'SU PAGO DEBE DE SER IGUAL QUE LA INSCRIPCION');
                return back();
            }
            $ab->abonoa = $request->abonoa;
        }
        if ($request->abonoa === 'ACTIVIDADES') {
            // ingrasar deuda ACTIVIDADES
            $venta = $this->abonaAexisit('ACTIVIDADES',  $request->estudiante_id, $request->valor);
            if ($venta === 0) return back()->with(['info' => 'no se puede abonar a actividades por que no se ha realizadon una venta', 'color' => 'danger']);
            $ab->abonoa = $request->abonoa;
        }
        if ($request->abonoa === 'DEUDA EXTRA') {
            // ingrasar deuda ACTIVIDADES
            $venta = $this->abonaAexisit('DEUDA EXTRA',  $request->estudiante_id, $request->valor);
            if ($venta === 0) return back()->with(['info' => 'no se puede abonar a  deuda extra por que no se ha realizadon una venta', 'color' => 'danger']);
            $ab->abonoa = $request->abonoa;
        }

        if ($request->abonoa === 'LIBROS') {
            // ingrasar deuda ACTIVIDADES
            $venta = $this->abonaAexisit('LIBROS',  $request->estudiante_id, $request->valor);
            if ($venta === 0) return back()->with(['info' => 'no se puede abonar a  libros por que no se ha realizadon una venta', 'color' => 'danger']);
            $ab->abonoa = $request->abonoa;
        }


        if ($ab->estado === 'PAGADO') {
            $this->asignarAbonoEstudiante($request->estudiante_id, $request->valor);
        }

        $ab->save();
        return back()->with(['info' => 'ABONO REALIZADO con exito', 'color' => 'success']);
    }

    // guarda / registra una factura
    public function guardarFactura(Request $request)
    {
        $factura = new Factura();
        $factura->estudiante_id = $request->estudiante_id;
        $factura->descripcion = $request->descripcion;
        $factura->total_cancelar = $request->valor;
        $factura->total_des = 0;
        $factura->total = $request->valor;
        $factura->aux1 = $request->mes;
        // dd($factura);
        $factura->save();
        return $factura;
    }

    // asigna un abono a un estudiante
    public function asignarAbonoEstudiante($id, $valor)
    {
        $estudiante = Estudiante::find($id);
        $estudiante->abono += $valor;
        return  $estudiante->save();
    }

    // elimina un abono de estudiante realizado
    public function deleteAbono($id)
    {
        $abono = Abonos::find($id);
        $estudiante = Estudiante::find($abono->estudiante_id);
        // cambiamos el total de los abonos en los estudiantes
        $estudiante->abono -= $abono->valor;
        // dd($estudiante);
        // dd($abono);
        $estudiante->save();
        $abono->delete();
        return back()->with(['info' => 'Abono eliminado con exito', 'color' => 'success']);
    }

    // imprime los abonos grupados por estudiante y por fectura/ recibo
    public function printRecibo($fecha, $factura, $estudiante)
    {

        $fecha = explode(' ', $fecha)[0];
        $abonos = Abonos::whereDate('created_at', $fecha)
            ->where('id', $factura)
            ->first();

        $estu = Estudiante::find($estudiante);
        $facturad = Factura::find($factura);
        // para determinar deudas
        $deuda_Bus = $this->deudaDeBuses($estu->id);
        $venta_uniformes = DB::table('venta_uniformes as ven')
            ->join('uniformes as uni', 'ven.uniforme_id', '=', 'uni.id')
            ->select('uni.nombre', 'uni.talla', 'uni.description', 'ven.cantidad', 'ven.descuento', 'ven.total', 'uni.p_venta')
            ->where('estudiante_id', $estu->id)
            ->where('ven.deleted_at', null)
            ->get();

        $venta_bolsas = DB::table('venta_bolsas as ven')
            ->join('bolsas as bol', 'ven.bolsa_id', '=', 'bol.id')
            ->select('ven.cantidad', 'ven.descuento', 'ven.total', 'bol.nombre', 'bol.p_venta', 'bol.decripcion', 'ven.factura_id', 'ven.created_at', 'ven.id')
            ->where('estudiante_id', $estu->id)
            ->where('ven.deleted_at', null)
            ->get();

        $deuda_extras = $this->deudas_extra($estu->id);
        $venta_actividades = $this->venta_actividad($estu->id);
        $deuda_colegiaturas = DeudaColegiatura::where('estudiante_id', $estu->id)->first();
        $deuda_inscripcion = DeudaInscripcion::where('estudiante_id', $estu->id)->first();
        $ab_actividad = AbonoActividad::select(DB::raw('sum(valor) as total'))->where('estudiante_id', $estu->id)->first()->total;

        $t_col = 0;
        $t_bus = 0;
        $t_bol = 0;
        $t_uni = 0;
        $t_act = 0;
        $t_ext = 0;
        $t_libros = 0;

        if ($deuda_Bus != null) {
            $t_bus =  $deuda_Bus->mes1 + $deuda_Bus->mes2 + $deuda_Bus->mes3 + $deuda_Bus->mes4 + $deuda_Bus->mes5 + $deuda_Bus->mes6 + $deuda_Bus->mes7 + $deuda_Bus->mes8 + $deuda_Bus->mes9 + $deuda_Bus->mes10;
        }

        $t_col += $deuda_colegiaturas->mes1 + $deuda_colegiaturas->mes2 + $deuda_colegiaturas->mes3 + $deuda_colegiaturas->mes4 + $deuda_colegiaturas->mes5 + $deuda_colegiaturas->mes6 + $deuda_colegiaturas->mes7 + $deuda_colegiaturas->mes8 + $deuda_colegiaturas->mes9 + $deuda_colegiaturas->mes10;

        foreach ($venta_bolsas as $vol) {
            $t_bol += $vol->total;
        }

        foreach ($venta_uniformes as $uni) {
            $t_uni += $uni->total;
        }

        foreach ($venta_actividades as $act) {
            $t_act += $act->total;
        }

        foreach ($deuda_extras as $value) {
            $t_ext += $value->valor;
        }

        $descuentos = $this->descuento($estu->id);
        $abonos2 = $this->getAbonos($estu->id);

        $venta_libros = VentaLibros::where('estudiante_id', $estu->id)->get();

        foreach ($venta_libros as $v_l) {
           $t_libros += $v_l->total;
        }

        return view('admin.reports.abono.recibo', [
            'abonos' => $abonos,
            'estudiante' => $estu,
            'fecha' => $fecha,
            'factura' => $factura,
            'facturad' => $facturad,
            'abonos2' => $abonos2,
            'total_bolsa' => $t_bol,
            'total_uniforme' => $t_uni,
            'total_actividad' => $t_act,
            'total_ext' => $t_ext,
            'total_colegiatura' => $t_col,
            'descuentos' => $descuentos,
            'total_bus' => $t_bus,
            'total_libros' => $t_libros,
            'venta_actividades' => $venta_actividades,
            'deuda_colegiatura' => $deuda_colegiaturas,
            'deuda_inscripcion' => $deuda_inscripcion,
            'ab_actividad' => $ab_actividad
        ]);
    }

    public function getAbonos($id)
    {
        $abonos = array();
        $inscripcion = $this->getTipeAbonos($id, 'INSCRIPCION');
        $colegiatura = $this->getTipeAbonos($id, 'COLEGIATURA');
        $bus = $this->getTipeAbonos($id, 'BUS');
        $bolsa = $this->getTipeAbonos($id, 'BOLSA DE UTILES');
        $libros = $this->getTipeAbonos($id, 'LIBROS');
        $uniformes = $this->getTipeAbonos($id, 'UNIFORME');
        $actividades = $this->getTipeAbonos($id, 'ACTIVIDADES');
        $deuda_extra = $this->getTipeAbonos($id, 'DEUDA EXTRA');
        array_push($abonos, $inscripcion, $colegiatura, $bus, $bolsa, $uniformes, $actividades, $deuda_extra, $libros);
        // dd($abonos);
        return $abonos;
    }

    public function getTipeAbonos($id, $tipo)
    {
        return Abonos::where('estudiante_id', $id)
            ->where('estado', 'PAGADO')
            ->where('abonoa', $tipo)
            ->orderBy('id', 'asc')
            ->get();
    }
    public function busAsignado($id)
    {
        return VentaBus::where('estudiante_id', $id)->first();
    }

    // / para ver el total de buses por cada mes (deuda de buses)
    public function deudaDeBuses($id)
    {
        return DeudaBus::where('estudiante_id', $id)->first();
    }
    public function deudas_extra($id)
    {
        return DeudaExtra::where('estudiante_id', $id)->get();
    }
    public function venta_actividad($id)
    {
        return  DB::table('venta_actividads as vn')
            ->join('actividades as ac', 'vn.actividad_id', '=', 'ac.id')
            ->select('vn.total', 'vn.estudiante_id', 'vn.description', 'ac.nombre', 'ac.descripcion', 'ac.costo', 'ac.fecha', 'vn.id')
            ->where('estudiante_id', $id)
            ->orderBy('vn.id', 'desc')
            ->get();
    }
    // retorna los descuentos de un estudiante
    public function descuento($id)
    {
        return DescuentoEstudiatens::where('estudiante_id', $id)->get();
    }

    // asigana el abono en Deuda de Colegiatura para comparar la deuda
    public function deudaColegiatura($estudiante, $mes, $valor)
    {
        $deuda = DeudaColegiatura::where('estudiante_id', $estudiante)->first();

        if ($mes === 'ENERO') {
            $deuda->abono1 = $valor;
            $deuda->estado1 = 'CANCELADO';
        }
        if ($mes === 'FEBRERO') {
            $deuda->abono2 = $valor;
            $deuda->estado2 = 'CANCELADO';
        }
        if ($mes === 'MARZO') {
            $deuda->abono3 = $valor;
            $deuda->estado3 = 'CANCELADO';
        }
        if ($mes === 'ABRIL') {
            $deuda->abono4 = $valor;
            $deuda->estado4 = 'CANCELADO';
        }
        if ($mes === 'MAYO') {
            $deuda->abono5 = $valor;
            $deuda->estado5 = 'CANCELADO';
        }
        if ($mes === 'JUNIO') {
            $deuda->abono6 = $valor;
            $deuda->estado6 = 'CANCELADO';
        }
        if ($mes === 'JULIO') {
            $deuda->abono7 = $valor;
            $deuda->estado7 = 'CANCELADO';
        }
        if ($mes === 'AGOSTO') {
            $deuda->abono8 = $valor;
            $deuda->estado8 = 'CANCELADO';
        }
        if ($mes === 'SEPTIEMBRE') {
            $deuda->abono9 = $valor;
            $deuda->estado9 = 'CANCELADO';
        }
        if ($mes === 'OCTUBRE') {
            $deuda->abono10 = $valor;
            $deuda->estado10 = 'CANCELADO';
        }
        $deuda->save();
    }

    // comprueba si existe el numero de transeferencia
    public function transferExisit(Request $request)
    {
        return Abonos::where('boleta', $request->boleta)->count();
        // dd($abono);

    }

    // =========================================
    // 	 	 	 MUESTRA LA VISTA PARA HACER EL ABONOS DESDE LA PAGINA WEB
    // ========================================= 
    public function webAbono()
    {
        return view('web.abono');
    }

    // =========================================
    // 	 	 	 GUARDA EL ABONO DESDE LA Web
    // ========================================= 

    public function storeAbonoWeb(Request $request)
    {

        $estudiante = Estudiante::where('cui', $request->cui)->first();
        if (!$estudiante) return back()->with(['info' => 'el numero de cui no esta registrado / abono no realizado', 'color' => 'danger']);

        // dd($estudiante);

        // dd($request->tipo);
        if ($request->tipo === 'DEPOSITO' || $request->tipo === 'TRANSFERENCIA') {
            $abono = $this->transferExisit($request);

            if ($abono > 0) {
                // dd('entro');
                return back()->with(['info' => 'boleta, ya registrada', 'color' => 'danger']);
            }
        }

        $ab = new AbonoWeb();
        $ab->estudiante_id = $estudiante->id;
        $ab->valor = $request->valor;
        $ab->descripcion = $request->descripcion;
        $ab->estado = 'PENDIENTE';
        $ab->tipo = $request->tipo;
        $ab->boleta = $request->boleta;

        if ($request->hasFile('foto')) {
            $file = $request->file('foto');
            $nombre = time() . $file->getClientOriginalName();
            $file->move(storage_path() . '/app/public/abonosweb', $nombre);
            $ab->foto = $nombre;
        }
        $ab->save();
        return back()->with(['info' => 'ABONO REALIZADO con exito', 'color' => 'success']);
    }

    // =========================================
    // 	 retorna la vista de los abonos realizados en la webAbono
    // ========================================= 

    public function abonoWweb()
    {
        $abono = DB::table('abono_webs as ab')
            ->join('estudiantes as es', 'ab.estudiante_id', '=', 'es.id')
            ->select('es.nombre', 'es.cui', 'es.id', 'ab.valor', 'ab.created_at', 'ab.tipo', 'ab.boleta', 'ab.descripcion', 'ab.foto')
            ->get();

        return view('admin.abonos.web', ['data' => $abono]);
    }


    // retorna la vista para ver los abonos por tipo y por fecha
    public function getAbonoToTipo(Request $request)
    {
        $grados = array();
        if ($request->grado_id[0] === 'TODOS') {
            $grados = Grado::all();
            $titulo = $request->abonoa . ' de ' . $request->inicio . ' al ' . $request->fin;
            $total = 0;
            $inicio = $request->inicio;
            $fin = $request->fin;
            $tipo = $request->abonoa;
            $st = 0;
            return view('admin.reports.caja.abonostipo', compact('titulo', 'total', 'grados', 'inicio', 'fin', 'tipo', 'st'));
        }
        for ($i = 0; $i < count($request->grado_id); $i++) {
            $data = Grado::find($request->grado_id[$i]);
            array_push($grados, $data);
        }
        $titulo = $request->abonoa . ' de ' . $request->inicio . ' al ' . $request->fin;
        $total = 0;
        $inicio = $request->inicio;
        $fin = $request->fin;
        $tipo = $request->abonoa;
        $st = 0;
        return view('admin.reports.caja.abonostipo', compact('data', 'titulo', 'total', 'grados', 'inicio', 'fin', 'tipo', 'st'));
    }


    // retorna la vista para ver el reporte de venta de uniformes a profesires
    public function getReporteProfesore(Request $request)
    {
        $data = VentaUnidormeProfeso::whereBetween('created_at', [$request->inicio, $request->fin])
            ->get();
        return view('admin.reports.uniformes.profe', compact('data'));
    }

    // bloquea un pago se un mes si no se ha cancelado el anterior
    public function bloqueoMesAnterior(Request $request)
    {
        switch ($request->mes) {
            case 'FEBRERO':
                return $this->valueMes('ENERO', $request->estudiante_id);
                break;
            case 'MARZO':
                return $this->valueMes('FEBRERO', $request->estudiante_id);
                break;
            case 'ABRIL':
                return $this->valueMes('MARZO', $request->estudiante_id);
                break;
            case 'MAYO':
                return $this->valueMes('ABRIL', $request->estudiante_id);
                break;
            case 'JUNIO':
                return $this->valueMes('MAYO', $request->estudiante_id);
                break;
            case 'JULIO':
                return $this->valueMes('JUNIO', $request->estudiante_id);
                break;
            case 'AGOSTO':
                return $this->valueMes('JULIO', $request->estudiante_id);

                break;
            case 'SEPTIEMBRE':
                return $this->valueMes('AGOSTO', $request->estudiante_id);

                break;
            case 'OCTUBRE':
                return $this->valueMes('SEPTIEMBRE', $request->estudiante_id);
                break;
            default:
                // dd('entro');
                return 0;
                break;
        }
    }

    public function valueMes($mes, $estudiante)
    {
        return Abonos::where(
            [
                ['estudiante_id', $estudiante],
                ['descripcion', 'like', '%' . $mes . '%'],
                ['abonoa', 'COLEGIATURA'],
            ]
        )->count();
    }


    // hace la validacion para corroborar que si existan datos para poder abonar 
    public function abonaAexisit($var, $id, $v_abono)
    {
        switch ($var) {
            case 'BUS':

                $ab = Abonos::where('estudiante_id', $id)->where('abonoa', $var)->get();
                $t = $v_abono;
                foreach ($ab as $v) {
                    $t = $t + $v->valor;
                }
                return  VentaBus::where('estudiante_id', $id)->count();
                break;

            case 'UNIFORME':
                $ab = Abonos::where('estudiante_id', $id)->where('abonoa', $var)->get();
                $t = $v_abono;
                foreach ($ab as $v) {
                    $t = $t + $v->valor;
                }
                $v = VentaUniforme::where('estudiante_id', $id)->get();
                $vt = 0;
                foreach ($v as $venta) {
                    $vt += $venta->total;
                }
                if ($vt == 0) return 'NO';
                $r = $t - $vt;
                // dd($r);
                return $r;
                break;

            case 'ACTIVIDADES':
                return VentaActividad::where('estudiante_id', $id)->count();
                break;

            case 'BOLSA DE UTILES':
                $ab = Abonos::where('estudiante_id', $id)->where('abonoa', $var)->get();
                $t = $v_abono;
                foreach ($ab as $v) {
                    $t = $t + $v->valor;
                }
                $v = VentaBolsa::where('estudiante_id', $id)->get();
                $vt = 0;
                foreach ($v as $venta) {
                    $vt += $venta->total;
                }
                if ($vt == 0) return 'NO';
                $r = $t - $vt;
                return $r;
                break;


            case 'LIBROS':
                $ab = Abonos::where('estudiante_id', $id)->where('abonoa', $var)->get();
                $t = $v_abono;
                foreach ($ab as $v) {
                    $t = $t + $v->valor;
                }
                $v = VentaLibros::where('estudiante_id', $id)->get();
                $vt = 0;
                foreach ($v as $venta) {
                    $vt += $venta->total;
                }
                if ($vt == 0) return 'NO';
                $r = $t - $vt;
                // dd($vt);
                return $r;
                break;

            case 'DEUDA EXTRA':
                return DeudaExtra::where('estudiante_id', $id)->count();
                break;
            default:
                return back();
                break;
        }
    }
}
