<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AbonoActividad;
use App\Models\Abonos;
use App\Models\Actividad;
use App\Models\Caja;
use App\Models\DeudaActividad;
use App\Models\Estudiante;
use App\Models\Factura;
use App\Models\Grado;
use App\Models\VentaActividad;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Symfony\Component\HttpKernel\HttpCache\Esi;

class ActividadController extends Controller
{
    public function index()
    {
        $actividades = DB::table('actividades as act')
            ->join('grados as gr', 'act.grado_id', '=', 'gr.id')
            ->select('act.id', 'act.nombre', 'act.descripcion', 'act.costo', 'act.fecha', 'gr.nombre as grado', 'gr.seccion')
            ->where('act.deleted_at', null)
            ->get();

        return view('admin.actividades.index', ['actividades' => $actividades]);
    }

    public function create()
    {
        $grado = Grado::all();
        return view('admin.actividades.create', ['grados' => $grado]);
    }

    public function store(Request $request)
    {


        if ($request->grado_id === 'TODOS') {
            $grado = Grado::all();

            foreach ($grado as $gr) {

                $a = new Actividad();
                $a->nombre = $request->nombre;
                $a->grado_id = $gr->id;
                $a->descripcion = $request->descripcion;
                $a->costo = $request->costo;
                $a->fecha = $request->fecha;
                $a->save();
                $estudiantes = Estudiante::where('grado_id', $gr->id)->get();

                foreach ($estudiantes as $estu) {
                    $activad = new VentaActividad();
                    $activad->estudiante_id = $estu->id;
                    $activad->actividad_id =  $a->id;
                    $activad->description = $request->descripcion;
                    $activad->total = $request->costo;
                    $dedua = new DeudaActividad();
                    $dedua->estudiante_id = $estu->id;
                    $dedua->deuda =  $request->costo;
                    $this->asignarDeudaEstudiante($estu->id, $request->costo);
                    $dedua->save();
                    $activad->save();
                }

            return back()->with(['info' => 'Actividades registradas con exito para todos los grados', 'color' => 'success']);

            }
        } else {
            $actividad = Actividad::create($request->all());
            $estudiantes = Estudiante::where('grado_id', $request->grado_id)->get();
            foreach ($estudiantes as $estu) {
                $activad = new VentaActividad();
                $activad->estudiante_id = $estu->id;
                $activad->actividad_id =  $actividad->id;
                $activad->description = $request->descripcion;
                $activad->total = $request->costo;
                $dedua = new DeudaActividad();
                $dedua->estudiante_id = $estu->id;
                $dedua->deuda =  $request->costo;
                $this->asignarDeudaEstudiante($estu->id, $request->costo);
                $dedua->save();
                $activad->save();
            }


            return back()->with(['info' => 'Actividad registrado con exito', 'color' => 'success']);
        }
    }

    public function show($id)
    {
        $actividades = DB::table('actividades as act')
            ->join('grados as gr', 'act.grado_id', '=', 'gr.id')
            ->select('act.id', 'act.nombre', 'act.descripcion', 'act.costo', 'act.fecha', 'gr.nombre as grado', 'gr.seccion', 'act.updated_at', 'gr.id as grado_id')
            ->where('act.id', $id)
            ->first();
        $grado = Grado::all();
        $estudiantes = Estudiante::where('grado_id', $actividades->grado_id)->get();

        return view('admin.actividades.show', ['actividad' => $actividades, 'grados' => $grado, 'estudiantes' => $estudiantes]);
    }

    public function delete($id)
    {
        $actividad = Actividad::findOrFail($id);

        $deuda = VentaActividad::where('actividad_id', $actividad->id)->get();

        foreach ($deuda as $deuda) {
            $estudiante = Estudiante::find($deuda->estudiante_id);
            $estudiante->deuda -= $deuda->total;
            $estudiante->save();
            $deuda->delete();
        }

        $actividad->delete();
        return back()->with(['info' => 'Actividad eliminado con exito', 'color' => 'success']);
    }

    public function update(Request $request, $id)
    {
        Actividad::findOrFail($id)->update($request->all());
        return back()->with(['info' => 'Actividad actualizado con exito', 'color' => 'success']);
    }

    // ---------------------------
    // VENTA / DEUDA  DE ACTIVIDAD
    // ---------------------------
    public function storeActivad(Request $request)
    {

        $activad_id  = explode('___', $request->actividad_id)[0];
        $activad = new VentaActividad();
        $activad->estudiante_id = $request->estudiante_id;
        $activad->actividad_id =  $activad_id;
        $activad->description = $request->description;
        $activad->total = $request->costo;

        $dedua = new DeudaActividad();
        $dedua->estudiante_id = $request->estudiante_id;
        $dedua->deuda =  $request->costo;
        $this->asignarDeudaEstudiante($request->estudiante_id, $request->costo);
        $dedua->save();
        $activad->save();

        return back()->with(['info' => 'Activiada Asignada con existo', 'color' => 'success']);
    }

    // asigna la deudan a un estudiante
    public function asignarDeudaEstudiante($id, $valor)
    {
        $estudiante = Estudiante::find($id);
        $estudiante->deuda += $valor;
        return  $estudiante->save();
    }

    // elimina una venta de ACTIVIDAD y remueve la deuda del estudiante
    public function deleteVenta($id)
    {
        $venta = VentaActividad::find($id);
        $estudiante = Estudiante::find($venta->estudiante_id);
        // cambiamos el total de las deudas en los estudiantes
        $estudiante->deuda -= $venta->total;
        $venta->delete();
        $estudiante->save();
        return back()->with(['info' => 'venta de uniforme elimida con exito', 'color' => 'success']);
    }

    // reportes
    // retorna el reporte de las actividades proximas
    public function allreport()
    {
        $act = Actividad::all();
        return view('admin.reports.actividad.all', ['data' => $act]);
    }

    // asigna los pagos de forma masiva dependiendo la activiadd
    public function store_pago_masivo(Request $request,  $actividad)
    {

        $actividad2 = Actividad::find($actividad);

        for ($i = 0; $i < count($request->estudiante_id); $i++) {
            $ab = new AbonoActividad();
            $ab->actividad_id = $actividad;
            $ab->estudiante_id = $request->estudiante_id[$i];
            $ab->user_id = Auth::user()->id;

            $ab->valor = $request->valor;
            $ab->descripcion = 'PAGO DE ' . $actividad2->nombre;
            $ab->tipo = 'EFECTIVO';
            $ab->save();
        }
        return back()->with(['info' => 'ABONO MASIVO con exito', 'color' => 'success']);
    }
}
