<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\ArticuloProveedor;
use App\Models\Bolsa;
use App\Models\CompraBolsaUtiles;
use App\Models\DeudaBolsa;
use App\Models\Estudiante;
use App\Models\Factura;
use App\Models\Grado;
use App\Models\ListaDeUtiles;
use App\Models\VentaBolsa;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class BolsaController extends Controller
{
    public function index()
    {
        return view('admin.bolsas.index', ['bolsas' => Bolsa::all()]);
    }

    public function create()
    {
        return view('admin.bolsas.create');
    }

    public function store(Request $request)
    {
        Bolsa::create($request->all());
        return back()->with(['info' => 'bolsa registrado con exito', 'color' => 'success']);
    }

    public function show($id)
    {
        return view('admin.bolsas.show', ['bolsa' => bolsa::findOrFail($id)]);
    }

    public function delete($id)
    {
        Bolsa::findOrFail($id)->delete();
        return back()->with(['info' => 'bolsa eliminado con exito', 'color' => 'success']);
    }

    public function update(Request $request, $id)
    {
        bolsa::findOrFail($id)->update($request->all());
        return back()->with(['info' => 'bolsa actualizado con exito', 'color' => 'success']);
    }


    // ---------------------------
    // VENTA DE BOLSAS
    // ---------------------------
    public function storeVenta(Request $request)
    {
        $factura = $this->guardarFactura($request);

        for ($i = 0; $i < count($request->id_bolsas); $i++) {
            $venta = new VentaBolsa();
            $venta->bolsa_id = $request->id_bolsas[$i];
            $venta->estudiante_id = $request->estudiante_id;
            $venta->factura_id = $factura->id;
            $venta->cantidad = $request->cantidad_bolsa[$i];
            $venta->descuento = $request->descuento_bolsa[$i];
            $venta->total = $request->subtotal_bolsa[$i];
            $venta->save();
            $bol = Bolsa::find($request->id_bolsas[$i]);
            $bol->stock -= $request->cantidad_bolsa[$i];
            $bol->save();
        }

        // para asignar deuda de uniformes de su tabla
        $deuda = DeudaBolsa::find($request->estudiante_id);
        if ($deuda) {
            $deuda->deuda +=  $factura->total;
            $deuda->save();
        } else {
            $deuda = new DeudaBolsa();
            $deuda->estudiante_id = $request->estudiante_id;
            $deuda->deuda = $factura->total;
            $deuda->save();
        }

        // asiganar deuda a estudiante 
        $this->asignarDeudaEstudiante($request->estudiante_id, $factura->total);

        if ($request->entregado_bolsa === 'SI') {
            $codigo = $request->lista;
            $listas = ListaDeUtiles::where('codigo', $codigo)->get();
            foreach ($listas as $lista) {
                $aux = ArticuloProveedor::find($lista->articulo_id);
                $aux->cantidad -= $lista->cantidad;
                $aux->save();
            }
        }

        return back()->with(['info' => 'bolsa de utiles vendidos con exito', 'color' => 'success']);
    }

    public function ventaRecibo($recibo, $estudiante)
    {
        $factura = DB::table('facturas as fac')
            ->join('estudiantes as estu', 'fac.estudiante_id', '=', 'estu.id')
            ->select('estu.nombre as estudiante', 'estu.cui', 'estu.id', 'fac.*')
            ->where('fac.id', $recibo)
            ->first();

        $uniformes = DB::table('venta_bolsas as v_bolsa')
            ->join('bolsas as bol', 'v_bolsa.bolsa_id', '=', 'bol.id')
            ->select('bol.*', 'v_bolsa.factura_id', 'v_bolsa.factura_id', 'v_bolsa.cantidad as cantidaComprada', 'v_bolsa.descuento', 'v_bolsa.total')
            ->where('v_bolsa.estudiante_id', $estudiante)
            ->where('v_bolsa.factura_id', $recibo)
            ->get();

        return view('admin.reports.bolsa.recibo', ['factura' => $factura, 'uniformes' => $uniformes]);
    }

    public function guardarFactura(Request $request)
    {
        // para facturas 
        $total_cancelar = 0;
        $total_des = 0;
        // end facturas
        $factura = new Factura();
        $factura->estudiante_id = $request->estudiante_id;
        $factura->descripcion = $request->descripcion;
        for ($i = 0; $i < count($request->id_bolsas); $i++) {
            $total_cancelar  += $request->bolsa_pventa_table[$i];
            $total_des += $request->descuento_bolsa[$i];
        }

        $factura->total_cancelar = $total_cancelar;
        $factura->total_des = $total_des;
        $factura->total = $request->totalventa_bolsa;

        $factura->save();
        return $factura;
    }

    // asigna la deudan a un estudiante
    public function asignarDeudaEstudiante($id, $deuda)
    {
        $estudiante = Estudiante::find($id);
        $estudiante->deuda += $deuda;
        return  $estudiante->save();
    }

    // elimina una venta de uniforme y remueve la deuda del estudiante
    public function deleteVenta($id)
    {
        $venta = VentaBolsa::find($id);
        $estudiante = Estudiante::find($venta->estudiante_id);
        // cambiamos el total de las deudas en los estudiantes
        $estudiante->deuda -= $venta->total;
        $bolsa = Bolsa::find($venta->bolsa_id);
        $bolsa->stock += $venta->cantidad;
        $bolsa->save();
        $venta->delete();
        $estudiante->save();

        return back()->with(['info' => 'venta de uniforme elimida con exito', 'color' => 'success']);
    }

    // retorna la vista para los Reportes
    public function reports()
    {
        $bolsa = Bolsa::all();
        $recibos = CompraBolsaUtiles::groupby('recibo')->get();
        return view('admin.bolsas.reportes', compact('bolsa', 'recibos'));
    }

    // retorna el reporte de toso las articulos registrados
    public function allBolsa()
    {
        $bol = Bolsa::all();
        return view('admin.reports.bolsa.all', ['bolsas' => $bol, 'visible' => true, 'nombre' => 'bolsas registradas']);
    }

    // retona el reporte de los articulos con minimo de stock
    public function minStockBolsa()
    {
        $bolsa = DB::table('bolsas')->whereColumn('stock', '<=', 'min_stock')->get();

        return view('admin.reports.bolsa.all', ['visible' => false, 'bolsas' => $bolsa, 'nombre' => 'bolsas con minimo de stock']);
    }

    // retorna el reporte para control de existencias
    public function controldeExisteicias()
    {
        $bol = Bolsa::all();
        return view('admin.reports.bolsa.all', ['bolsas' => $bol, 'visible' => false, 'nombre' => 'bolsas registradas']);
    }

    // retorna el reported de las ventas de uniformes por mes
    public function reportVentas(Request $request)
    {

        $ventas =  DB::table('venta_bolsas as ven')
            ->join('bolsas as bol', 'ven.bolsa_id', '=', 'bol.id')
            ->select('ven.cantidad', 'ven.descuento', 'ven.factura_id', 'ven.total', 'ven.created_at', 'bol.*')
            ->whereBetween('ven.created_at', [$request->inicio, $request->fin])
            ->where('ven.deleted_at', null)
            ->get();

        $t_sin = 0;
        $t_con = 0;
        $t_des = 0;
        $t_gan = 0;

        return view('admin.reports.bolsa.ventas', ['ventas' => $ventas, 'mes' => $request->mes, 't_gan' => $t_gan, 't_des' => $t_des, 't_con' => $t_con, 't_sin' => $t_sin]);
    }




    // retorn el historial de compra de bolsa de utiles
    public function reporte_historial(Request $request)
    {
        $articulos =
            DB::table('compra_bolsa_utiles as com')
            ->join('bolsas as bol', 'com.bolsa_id', '=', 'bol.id')
            ->join('users as u', 'com.user_id', '=', 'u.id')
            ->select('bol.*', 'com.*', 'u.*', 'com.id as compraId', 'com.created_at as f_compra',)
            ->whereBetween('com.created_at', [$request->inicio, $request->fin])
            ->get();
        return view('admin.reports.bolsa.historial', compact('articulos'));
    }

    public function reporte_historial_agrupado(Request $request)
    {
        $articulos =
            DB::table('compra_bolsa_utiles as com')
            ->join('bolsas as bol', 'com.bolsa_id', '=', 'bol.id')
            ->join('users as u', 'com.user_id', '=', 'u.id')
            ->select('bol.*', 'com.*', 'u.*', 'com.id as compraId',  DB::raw('Sum(com.cantidad) as ctcompra'), 'com.created_at as f_compra',)
            ->whereBetween('com.created_at', [$request->inicio, $request->fin])
            ->groupBy('bol.id')
            ->get();


        return view('admin.reports.bolsa.compraunidas', compact('articulos'));
    }


    public function ventas_agrupados_detallado(Request $request)
    {
        $ventas = [];
        for ($i = 0; $i < count($request->bolsa_id); $i++) {
            # code...
            $venta =  DB::table('venta_bolsas as ven')
                ->join('bolsas as bol', 'ven.bolsa_id', '=', 'bol.id')
                ->select('ven.cantidad', 'ven.descuento', 'ven.factura_id', 'ven.total', 'ven.created_at', 'bol.*')
                ->whereBetween('ven.created_at', [$request->inicio, $request->fin])
                ->where('bol.id', $request->bolsa_id[$i])
                ->where('ven.deleted_at', null)
                ->get();
            array_push($ventas, $venta);
        }

        $bolsa = Bolsa::find($request->bolsa_id);
        $t_sin = 0;
        $t_con = 0;
        $t_des = 0;
        $t_gan = 0;
        return view('admin.reports.bolsa.ventasDetalladas', ['ventas' => $ventas, 'mes' => $request->mes, 't_gan' => $t_gan, 't_des' => $t_des, 't_con' => $t_con, 't_sin' => $t_sin,]);
    }

    public function ventas_agrupados(Request $request)
    {
        $bolsa = Bolsa::all();

        $inicio = $request->inicio;
        $fin = $request->fin;

        return view('admin.reports.bolsa.ventasAgrupadas', compact(
            'bolsa',
            'inicio',
            'fin',

        ));
    }

    public function getBolsaToReciboAndFecha(Request $request)
    {
        $compras = [];
        for ($i = 0; $i < count($request->bolsa_id); $i++) {
            $d = CompraBolsaUtiles::where('recibo', $request->bolsa_id[$i])->whereBetween('f_compra', [$request->inicio, $request->fin])->get();
            array_push($compras, $d);
        }
        return view('admin.reports.bolsa.comprasreports', compact('compras'));
    }

    function listDB()
    {
        $bolsa = Bolsa::all();
        return view('admin.bolsas.listdb', compact('bolsa'));
    }

    function saveToDB(Request $request)
    {

        for ($i = 0; $i < count($request->id); $i++) {
            $u = Bolsa::find($request->id[$i]);
            $u->stock = $request->stock[$i];
            $u->fisico = $request->fisico[$i];
            $u->p_venta = $request->p_ventas[$i];
            $u->save();
        }
        return back()->with(['info' =>  'DATOS ACTUALIZADOS', 'color'   => 'success']);
    }

    function code_print($id)
    {
        $articulo = Bolsa::find($id);
        return view('admin.reports.bolsa.code', ['articulo' => $articulo]);
    }

    // retorna las ventas por estado de pendiendo la fecha 
    public function estaddeVentas(Request $request)
    {

        $ventas = null;
        $vis = false;
        $grado_id = null;
        if ($request->estado) {
            $ventas =
                VentaBolsa::where('entregado', $request->estado)
                ->with('estudiante')
                ->whereBetween('created_at', [$request->inicio, $request->fin])
                ->get();
            $vis = true;
            $grado_id = $request->grado_id;
        }

        $listas = ListaDeUtiles::groupby('codigo')->get();
        $grados = Grado::all();

        return view('admin.bolsas.estados', compact('ventas', 'vis', 'listas', 'grados', 'grado_id'));
    }

    // NIEGA el "entregado " de un venta
    public function changeEntregado(Request $request, $id)
    {
        $venta = VentaBolsa::find($id);
        switch ($venta->entregado) {
            case 'SI':
                $venta->entregado = 'NO';

                break;
            case 'NO':
                $venta->entregado = 'SI';
                $listas = ListaDeUtiles::where('codigo', $request->codigo)->get();
                foreach ($listas as $lista) {
                    $aux = ArticuloProveedor::find($lista->articulo_id);
                    $aux->cantidad -= $lista->cantidad;
                    $aux->save();
                }
                break;
            default:
                dd('sin datos');
                break;
        }
        $venta->save();
        return back()->with(['info' => 'datos actualizados', 'color' => 'success']);
    }
}
