<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AbonoActividad;
use App\Models\Abonos;
use App\Models\Caja;
use App\Models\ControlCuadre;
use App\Models\Cuadre;
use App\Models\Grado;
use App\Models\OperacionGrado;
use App\Models\VentaArticulo;
use App\Models\VentaBus;
use App\Models\VentaUnidormeProfeso;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class CajaController extends Controller
{
    public function showEntrdas()
    {
        $entrada = Caja::where('user_id', Auth::user()->id)
            ->get();
        $total = 0;

        foreach ($entrada as $ent) {
            $total =  $total + $ent->valor;
        }

        return view('admin.caja.entradas', ['entradas' => $entrada, 'total' => $total]);
    }

    public function showSalidas()
    {
        $entrada = DB::table('cajas')
            ->where('operacion', 'e')
            ->whereDate('fecha', date('Y-m-d'))
            ->where('user_id', Auth::user()->id)
            ->get();
        $total = 0;

        foreach ($entrada as $ent) {
            $total =  $total + $ent->valor;
        }

        return view('admin.caja.salidas', ['entradas' => $entrada, 'total' => $total]);
    }

    // guarda una entrada 
    public function entrada(Request $data)
    {
        $caja = new Caja();
        $caja->valor = $data->valor;
        $caja->descripcion = $data->descripcion;
        $caja->operacion = 'e';
        $caja->fecha = date('Y-m-d');
        $caja->user_id = Auth::user()->id;
        $caja->save();
        return back()->with(['info' => 'Entrada Registrada Con Exito', 'color' => 'success']);
    }

    // guarda una salida
    public function salida(Request $data)
    {

        $caja = new Caja();
        $caja->valor = $data->valor;
        $caja->descripcion = $data->descripcion;
        $caja->operacion = 's';
        $caja->factura = $data->factura;
        $caja->tipo = $data->tipo;
        $caja->fecha = date('Y-m-d');
        $caja->user_id = Auth::user()->id;

        $caja->save();
        return back()->with(['info' => 'Salida de Efectivo Registrada Con Exito', 'color' => 'success']);
    }

    // devuelve un listado de las entradas
    public function listentrada()
    {
        $entrada = DB::table('cajas')
            ->where('operacion', 'e')
            ->whereDate('fecha', date('Y-m-d'))
            ->get();
        return $entrada;
    }

    // devuele un listado de las salidas
    public function listsalida()
    {
        $salida = DB::table('cajas')
            ->where('operacion', 's')
            ->whereDate('fecha', date('Y-m-d'))
            ->get();
        return $salida;
    }

    // muestra la vista para cuader de caja
    public function cuadre()
    {
        $salida = DB::table('cajas')
            ->where('operacion', 'e')
            ->whereDate('fecha', date('Y-m-d'))
            ->get();

        $totalSalida = 0;
        foreach ($salida as $sal) {
            $totalSalida = $sal->valor + $totalSalida;
        }

        $entrada = DB::table('cajas')
            ->where('operacion', 'e')
            ->whereDate('fecha', date('Y-m-d'))
            ->get();
        $totalEntrada = 0;
        foreach ($entrada as $ent) {
            $totalEntrada = $totalEntrada + $ent->valor;
        }

        $colegiatura = $this->getTipoPago(date('Y-m-d'), 'COLEGIATURA');
        $inscripcion = $this->getTipoPago(date('Y-m-d'), 'INSCRIPCION');
        $bus = $this->getTipoPago(date('Y-m-d'), 'BUS');
        $bolsa = $this->getTipoPago(date('Y-m-d'), 'BOLSA DE UTILES');
        $uniforme = $this->getTipoPago(date('Y-m-d'), 'UNIFORME');
        $actividad = $this->getTipoPago(date('Y-m-d'), 'ACTIVIDADES');
        $extra = $this->getTipoPago(date('Y-m-d'), 'DEUDA EXTRA');
        $libros = $this->getTipoPago(date('Y-m-d'), 'LIBROS');

        $abonos = $this->getAbonos(date('Y-m-d'));


        $uniprofe = VentaUnidormeProfeso::whereDate('created_at', date('Y-m-d'))->get();
        $tup = 0;

        foreach ($uniprofe as $d) {
            $tup += ($d->uniforme->p_venta * $d->cantidad);
        }

        $t_abonoActi = 0;
        foreach (AbonoActividad::whereDate('created_at', date('Y-m-d'))->get() as $v) {
            $t_abonoActi += $v->valor;
        }

        $t_articulos = 0;
        $articulos = VentaArticulo::whereDate('created_at', date('Y-m-d'))->where('credito', null)->get();
        foreach ($articulos as $a) {
            $t_articulos += $a->p_venta * $a->cantidad;
        }

        foreach (OperacionGrado::where('operacion', 'abn')->whereDate('created_at', date('Y-m-d'))->get() as $o) {
            $t_articulos += $o->valor;
        }

        return view('admin.caja.cuadre', [
            'entradas' => $totalEntrada,
            'salida' => $totalSalida,
            'abonos' => $abonos,
            'colegiatura' => $colegiatura,
            'inscripcion' => $inscripcion,
            'bus' => $bus,
            'bolsa' => $bolsa,
            'uniforme' => $uniforme,
            'actividad' => $actividad,
            'extra' => $extra,
            'tup' => $tup,
            'abono_acti' => $t_abonoActi,
            'libros' => $libros,
            'articulos' => $t_articulos,
        ]);
    }

    // retorna la vista para realizar el cuadre de caja de un dia anterior
    public function cuadreAyer($fecha)
    {
        $salida = DB::table('cajas')
            ->where('operacion', 'e')
            ->whereDate('fecha', $fecha)
            ->where('user_id', Auth::user()->id)
            ->get();

        $totalSalida = 0;
        foreach ($salida as $sal) {
            $totalSalida = $sal->valor + $totalSalida;
        }

        $entrada = DB::table('cajas')
            ->where('operacion', 'e')
            ->whereDate('fecha', $fecha)
            ->where('user_id', Auth::user()->id)
            ->get();
        $totalEntrada = 0;
        foreach ($entrada as $ent) {
            $totalEntrada = $totalEntrada + $ent->valor;
        }

        $colegiatura = $this->getTipoPago($fecha, 'COLEGIATURA');
        $inscripcion = $this->getTipoPago($fecha, 'INSCRIPCION');
        $bus = $this->getTipoPago($fecha, 'BUS');
        $bolsa = $this->getTipoPago($fecha, 'BOLSA DE UTILES');
        $uniforme = $this->getTipoPago($fecha, 'UNIFORME');
        $actividad = $this->getTipoPago($fecha, 'ACTIVIDADES');
        $extra = $this->getTipoPago($fecha, 'DEUDA EXTRA');
        $libros = $this->getTipoPago($fecha, 'LIBROS');

        $abonos = $this->getAbonos($fecha);


        $uniprofe = VentaUnidormeProfeso::whereDate('created_at', $fecha)->get();
        $tup = 0;

        foreach ($uniprofe as $d) {
            $tup += ($d->uniforme->p_venta * $d->cantidad);
        }

        $t_abonoActi = 0;
        foreach (AbonoActividad::whereDate('created_at', $fecha)->get() as $v) {
            $t_abonoActi += $v->valor;
        }


        $t_articulos = 0;
        $articulos = VentaArticulo::whereDate('created_at', $fecha)->where('credito', null)->get();
        foreach ($articulos as $a) {
            $t_articulos += $a->p_venta * $a->cantidad;
        }

        foreach (OperacionGrado::where('operacion', 'abn')->whereDate('created_at', $fecha)->get() as $o) {
            $t_articulos += $o->valor;
        }

        return view('admin.caja.cuadreayer', [
            'entradas' => $totalEntrada,
            'salida' => $totalSalida,
            'abonos' => $abonos,
            'colegiatura' => $colegiatura,
            'inscripcion' => $inscripcion,
            'bus' => $bus,
            'bolsa' => $bolsa,
            'uniforme' => $uniforme,
            'actividad' => $actividad,
            'extra' => $extra,
            'tup' => $tup,
            'abono_acti' => $t_abonoActi,
            'libros' => $libros,
            'ayer' => $fecha,
            'articulos' => $t_articulos,

        ]);
    }

    // guarda un cuadre con la fecha del dia de "ayer"
    public function cuadreStoreAyer(Request $data, $fecha)
    {
        $cuadre = new Cuadre();
        $cuadre->entrada = $data->entrada;
        $cuadre->salida = $data->salida;
        $cuadre->cuadre = $data->cuadre;
        $cuadre->totalEfectico = $data->efectivo;
        $cuadre->faltante = $data->faltante;
        $cuadre->totalVisas = $data->visas;
        $cuadre->user_id = Auth::user()->id;
        $cuadre->created_at = $fecha . ' ' . date('h:i:s');
        $cuadre->save();
        $this->store_control_cuadre($data,  $fecha . ' ' . date('h:i:s'));
        return back()->with(['info' => 'Cuadre Registrado', 'color' => 'success']);
    }

    // guarda un cuadre de caja
    public function cuadreStore(Request $data)
    {

        $cuadre = new Cuadre();
        $cuadre->entrada = $data->entrada;
        $cuadre->salida = $data->salida;
        $cuadre->cuadre = $data->cuadre;
        $cuadre->totalEfectico = $data->efectivo;
        $cuadre->faltante = $data->faltante;
        $cuadre->totalVisas = $data->visas;
        $cuadre->user_id = Auth::user()->id;
        $this->store_control_cuadre($data, date('Y-m-d h:i:s'));

        $cuadre->save();
        return back()->with(['info' => 'Cuadre Del Dia Registrado', 'color' => 'success']);
    }

    // reporte para el cuadre de la caja
    public function cuadrereport()
    {
        $cuadres = Cuadre::orderBy('created_at', 'ASC')->whereMonth('created_at', date('m'))->get();
        return view('admin.reports.caja.cuadre', ['cuadres' => $cuadres]);
    }

    public function deleteCuadre($id)
    {
        $caudre = Cuadre::find($id);
        $caudre->delete();
        return back()->with(['info' => "Cuadre del Dia $caudre->fecha eliminado con Exito", 'color' => 'danger']);
    }

    public function salidaDelete($id)
    {
        $caja = Caja::find($id);
        $caja->delete();
        return back()->with(['info' => "Salida Eliminada Con exito", 'color' => 'danger']);
    }

    public function entradaDelete($id)
    {
        $caja = Caja::find($id);
        $caja->delete();
        return back()->with(['info' => "Entrada Eliminada Con exito", 'color' => 'danger']);
    }

    // retorna la vista para porder generar reportes de caja
    public function movimientos()
    {
        $grados = Grado::all();
        return view('admin.caja.movimientos', compact('grados'));
    }

    // retorna el Reporte de Salidas Filtrado por fecha
    public function salidaReport(Request $request)
    {

        $data = $this->operacionFilter($request, 's');
        $total = 0;
        foreach ($data as $ta) {
            $total = $total + $ta->valor;
        }
        return view('admin.reports.caja.salidas', ['data' => $data, 'total' => $total]);
    }

    // retorna reporte de Entradas Filtradas por fecha
    public function entradasReport(Request $request)
    {
        $data = $this->operacionFilter($request, 'e');
        $total = 0;
        foreach ($data as $ta) {
            $total = $total + $ta->valor;
        }
        return view('admin.reports.caja.entradas', ['data' => $data, 'total' => $total]);
    }


    // funcios para retornar el listado de operacion deseadas
    public function operacionFilter(Request $request, $operacion)
    {
        $data = Caja::where('operacion', $operacion)
            ->whereBetween('fecha', [$request->desde, $request->hasta])->get();
        return $data;
    }

    // retorna el total de cuadre por fecha
    // TODO: modificar para que tenga las variables de movimiento en especifico ($request->fecha)
    public function cuadreFecha($fecha)
    {
        $salidas =  DB::table('cajas')
            ->where('operacion', 's')
            ->whereDate('fecha', $fecha)
            ->get();
        $entradas = DB::table('cajas')
            ->where('operacion', 'e')
            ->whereDate('fecha', $fecha)
            ->get();

        $abonos_list = DB::table('abonos as ab')
            ->join('estudiantes as es', 'ab.estudiante_id', '=', 'es.id')
            ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
            ->join('users as us', 'ab.user_id', '=', 'us.id')
            ->select(
                'ab.*',
                'es.nombre as nombre_estudiante',
                'es.cui',
                'gr.nombre',
                'gr.seccion',
                'gr.nivel',
                'es.jornada',
                'us.name'
            )
            ->where('ab.deleted_at', '=', null)
            ->whereDate('ab.created_at', $fecha)
            ->get();

        $inscripcion =
            DB::table('estudiantes as es')
            ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
            ->join('encargados as en', 'es.encargado_id', '=', 'en.id')
            ->select('gr.nombre as grado', 'gr.nivel as nivel', 'gr.seccion',  'es.*', 'en.nombre1 as encargado', 'en.telefono1', 'en.telefono2', 'en.nombre2', 'en.telefono3', 'en.telefono4')
            ->where('ciclo', config('app.cliclo'))
            ->where('es.deleted_at', null)
            ->whereDate('es.created_at', $fecha)
            ->get();
        $abonos = $this->getAbonos($fecha);

        // VENTAS DE UNIFORMES
        $ventas_uniforme =  DB::table('venta_uniformes as ven')
            ->join('uniformes as uni', 'ven.uniforme_id', '=', 'uni.id')
            ->select('ven.cantidad', 'ven.descuento', 'ven.factura_id', 'ven.total', 'ven.created_at', 'uni.*')
            ->whereDate('ven.created_at', $fecha)
            ->where('ven.deleted_at', null)
            ->get();

        $tu_sin = 0;
        $tu_con = 0;
        $tu_des = 0;
        $tu_gan = 0;

        // TODO: VENTAS DE UTILES

        $ventas_bolsa =  DB::table('venta_bolsas as ven')
            ->join('bolsas as bol', 'ven.bolsa_id', '=', 'bol.id')
            ->select('ven.cantidad', 'ven.descuento', 'ven.factura_id', 'ven.total', 'ven.created_at', 'bol.*')
            ->whereDAte('ven.created_at', $fecha)
            ->where('ven.deleted_at', null)
            ->get();

        $tb_sin = 0;
        $tb_con = 0;
        $tb_des = 0;
        $tb_gan = 0;

        //  VENTAS DE BUSES
        $venta_bus = VentaBus::whereDate('created_at', $fecha)->get();


        $venta_articulos = VentaArticulo::whereDate('created_at', $fecha)->get();
        $operaciones = OperacionGrado::whereDate('created_at', $fecha)->get();

        $compra_uni =
            DB::table('compra_uniformes as com')
            ->join('uniformes as uni', 'com.unifrome_id', '=', 'uni.id')
            ->join('users as u', 'com.user_id', '=', 'u.id')
            ->select('uni.*', 'com.*', 'u.*', 'com.id as compraId')
            ->whereDate('com.created_at', $fecha)
            ->get();

        //  COMPRA DE UTILES
        $compra_bolsa =
            DB::table('compra_bolsa_utiles as com')
            ->join('bolsas as bol', 'com.bolsa_id', '=', 'bol.id')
            ->join('users as u', 'com.user_id', '=', 'u.id')
            ->select('bol.*', 'com.*', 'u.*', 'com.id as compraId')
            ->whereDate('com.created_at', $fecha)
            ->get();

        return view(
            'admin.reports.caja.fecha',
            compact(
                'salidas',
                'entradas',
                'abonos',
                'abonos_list',
                'inscripcion',
                'ventas_uniforme',
                'tu_sin',
                'tu_con',
                'tu_des',
                'tu_gan',
                'compra_uni',
                'ventas_bolsa',
                'tb_sin',
                'tb_con',
                'tb_des',
                'tb_gan',
                'compra_bolsa',
                'venta_bus',
                'venta_articulos',
                'operaciones',
            )

        );
    }

    // retorna la vista para cuadre filtrado por mes y año 
    public function cuadrereportFilter(Request $request)
    {
        $cuadres = Cuadre::whereMonth('created_at', $request->mes)
            ->whereYear('created_at', $request->ano)
            ->orderBy('created_at', 'desc')
            ->get();
        return view('admin.reports.caja.cuadre', ['cuadres' => $cuadres]);
    }

    // retorna el arreglo de los abonos realizados por fecha
    public function getAbonos($date)
    {
        $abonos = array();
        $efectivo = $this->getTiposAbonos('EFECTIVO', $date);
        $visa = $this->getTiposAbonos('VISA', $date);
        $cheque = $this->getTiposAbonos('CHEQUE', $date);
        $transeferencia = $this->getTiposAbonos('TRANSFERENCIA', $date);
        $deposito = $this->getTiposAbonos('DEPOSITO', $date);
        $otro = $this->getTiposAbonos('OTRO', $date);

        $t_efectivo = 0;
        $t_visa = 0;
        $t_cheque = 0;
        $t_transeferencia = 0;
        $t_deposito = 0;
        $t_otro = 0;

        foreach ($efectivo as $data) {
            $t_efectivo += $data->valor;
        }
        foreach ($visa as $data) {
            $t_visa += $data->valor;
        }
        foreach ($cheque as $data) {
            $t_cheque += $data->valor;
        }
        foreach ($transeferencia as $data) {
            $t_transeferencia += $data->valor;
        }
        foreach ($deposito as $data) {
            $t_deposito += $data->valor;
        }
        foreach ($otro as $data) {
            $t_otro += $data->valor;
        }

        array_push($abonos, $t_efectivo, $t_visa, $t_cheque, $t_transeferencia, $t_deposito, $t_otro);


        return $abonos;
    }

    // retorna los abonos por tipo y por fecha
    public function getTiposAbonos($tipo, $date)
    {
        return DB::table('abonos')
            ->select('*')
            ->where('tipo', $tipo)
            ->whereDate('created_at', $date)
            ->where('user_id', Auth::user()->id)
            ->where('deleted_at', '=', null)
            ->get();
    }

    // retorna el reporte de los gastos agrupados por tipo y por fecha
    public function gasto_tipo_fecha(Request $request)
    {
        $data = DB::table('cajas')
            ->select('*')
            ->where('operacion', 's')
            ->where('tipo', $request->tipo)
            ->whereMonth('created_at', $request->mes)
            ->get();
        $total = 0;
        foreach ($data as $ta) {
            $total = $total + $ta->valor;
        }

        return view('admin.reports.caja.salidas', ['data' => $data, 'total' => $total]);
    }

    // retorna los movimientos de un dia en especifico sin necesidad de realizar un cuadre
    public function getMovimientoToData(Request $request)
    {
        $salidas =  DB::table('cajas')
            ->where('operacion', 's')
            ->whereBetween('created_at', [$request->inicio, $request->fin])
            ->get();
        $entradas = DB::table('cajas')
            ->where('operacion', 'e')
            ->whereBetween('created_at', [$request->inicio, $request->fin])
            ->get();

        $abonos_list = DB::table('abonos as ab')
            ->join('estudiantes as es', 'ab.estudiante_id', '=', 'es.id')
            ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
            ->join('users as us', 'ab.user_id', '=', 'us.id')
            ->select(
                'ab.*',
                'es.nombre as nombre_estudiante',
                'es.cui',
                'gr.nombre',
                'gr.seccion',
                'gr.nivel',
                'es.jornada',
                'us.name'
            )
            ->where('ab.deleted_at', '=', null)
            ->whereBetween('ab.created_at', [$request->inicio, $request->fin])
            ->get();

        $inscripcion =
            DB::table('estudiantes as es')
            ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
            ->join('encargados as en', 'es.encargado_id', '=', 'en.id')
            ->select('gr.nombre as grado', 'gr.nivel as nivel', 'gr.seccion',  'es.*', 'en.nombre1 as encargado', 'en.telefono1', 'en.telefono2', 'en.nombre2', 'en.telefono3', 'en.telefono4')
            ->where('ciclo', config('app.cliclo'))
            ->where('es.deleted_at', null)
            ->whereBetween('es.created_at', [$request->inicio, $request->fin])
            ->get();


        $abonos = $this->getAbonosToDate($request->inicio, $request->fin);

        // VENTAS DE UNIFORMES
        $ventas_uniforme =  DB::table('venta_uniformes as ven')
            ->join('uniformes as uni', 'ven.uniforme_id', '=', 'uni.id')
            ->select('ven.cantidad', 'ven.descuento', 'ven.factura_id', 'ven.total', 'ven.created_at', 'uni.*')
            ->whereBetween('ven.created_at', [$request->inicio, $request->fin])

            ->where('ven.deleted_at', null)
            ->get();

        $tu_sin = 0;
        $tu_con = 0;
        $tu_des = 0;
        $tu_gan = 0;

        // TODO: VENTAS DE UTILES

        $ventas_bolsa =  DB::table('venta_bolsas as ven')
            ->join('bolsas as bol', 'ven.bolsa_id', '=', 'bol.id')
            ->select('ven.cantidad', 'ven.descuento', 'ven.factura_id', 'ven.total', 'ven.created_at', 'bol.*')
            ->whereBetween('ven.created_at', [$request->inicio, $request->fin])
            ->where('ven.deleted_at', null)
            ->get();

        $tb_sin = 0;
        $tb_con = 0;
        $tb_des = 0;
        $tb_gan = 0;

        //  VENTAS DE BUSES
        $venta_bus = VentaBus::whereBetween('created_at', [$request->inicio, $request->fin])->get();
        // dd($venta_bus);



        $venta_articulos = VentaArticulo::whereBetween('created_at', [$request->inicio, $request->fin])->get();
        $operaciones = OperacionGrado::whereBetween('created_at', [$request->inicio, $request->fin])->get();

        // COMPRA DE UNIFORMES

        $compra_uni =
            DB::table('compra_uniformes as com')
            ->join('uniformes as uni', 'com.unifrome_id', '=', 'uni.id')
            ->join('users as u', 'com.user_id', '=', 'u.id')
            ->select('uni.*', 'com.*', 'u.*', 'com.id as compraId')
            ->whereBetween('com.created_at', [$request->inicio, $request->fin])
            ->get();

        //  COMPRA DE UTILES
        $compra_bolsa =
            DB::table('compra_bolsa_utiles as com')
            ->join('bolsas as bol', 'com.bolsa_id', '=', 'bol.id')
            ->join('users as u', 'com.user_id', '=', 'u.id')
            ->select('bol.*', 'com.*', 'u.*', 'com.id as compraId')
            ->whereBetween('com.created_at', [$request->inicio, $request->fin])
            ->get();

        return view(
            'admin.reports.caja.fecha',
            compact(
                'salidas',
                'entradas',
                'abonos',
                'abonos_list',
                'inscripcion',
                'ventas_uniforme',
                'tu_sin',
                'tu_con',
                'tu_des',
                'tu_gan',
                'compra_uni',
                'ventas_bolsa',
                'tb_sin',
                'tb_con',
                'tb_des',
                'tb_gan',
                'compra_bolsa',
                'venta_bus',
                'venta_articulos',
                'operaciones',
            )
        );
    }

    public function getAbonosToDate($inicio, $fin)
    {
        $abonos = array();
        $efectivo = $this->getTiposAbonosToDate('EFECTIVO', $inicio, $fin);
        $visa = $this->getTiposAbonosToDate('VISA', $inicio, $fin);
        $cheque = $this->getTiposAbonosToDate('CHEQUE', $inicio, $fin);
        $transeferencia = $this->getTiposAbonosToDate('TRANSFERENCIA', $inicio, $fin);
        $deposito = $this->getTiposAbonosToDate('DEPOSITO', $inicio, $fin);
        $otro = $this->getTiposAbonosToDate('OTRO', $inicio, $fin);

        $t_efectivo = 0;
        $t_visa = 0;
        $t_cheque = 0;
        $t_transeferencia = 0;
        $t_deposito = 0;
        $t_otro = 0;

        foreach ($efectivo as $data) {
            $t_efectivo += $data->valor;
        }
        foreach ($visa as $data) {
            $t_visa += $data->valor;
        }
        foreach ($cheque as $data) {
            $t_cheque += $data->valor;
        }
        foreach ($transeferencia as $data) {
            $t_transeferencia += $data->valor;
        }
        foreach ($deposito as $data) {
            $t_deposito += $data->valor;
        }
        foreach ($otro as $data) {
            $t_otro += $data->valor;
        }

        array_push($abonos, $t_efectivo, $t_visa, $t_cheque, $t_transeferencia, $t_deposito, $t_otro);


        return $abonos;
    }

    public function getTiposAbonosToDate($tipo, $inicio, $fin)
    {
        return DB::table('abonos')
            ->select('*')
            ->where('tipo', $tipo)
            ->where('deleted_at', '=', null)
            ->whereBetween('created_at', [$inicio, $fin])
            ->get();
    }

    // retorna los abonos por tipo de pago 'bus, colegiatura, ...'
    public function getTipoPago($fecha, $tipo)
    {
        return Abonos::select(DB::raw('SUM(valor) as total'))
            ->where('abonoa', $tipo)
            ->whereDate('created_at', $fecha)
            ->first();
    }

    // para realizar la impresion de caja chica
    public function prit_caja_chcia(Caja $caja)
    {
        return view('admin.reports.caja.printEntrada', compact('caja'));
    }

    // para derterminar si se hara cun control de cuadre de caja con su tipo
    public function store_control_cuadre(Request $request, $fecha)
    {
        if ($request->t_colegiatura > 0) ControlCuadre::create(['monto' => $request->t_colegiatura, 'tipo' => 'colegiatura', 'created_at' => $fecha]);
        if ($request->t_inscripcion > 0) ControlCuadre::create(['monto' => $request->t_inscripcion, 'tipo' => 'inscripcion', 'created_at' => $fecha]);
        if ($request->t_bus > 0) ControlCuadre::create(['monto' => $request->t_bus, 'tipo' => 'bus', 'created_at' => $fecha]);
        if ($request->t_bolsa > 0) ControlCuadre::create(['monto' => $request->t_bolsa, 'tipo' => 'bolsa', 'created_at' => $fecha]);
        if ($request->t_libro > 0) ControlCuadre::create(['monto' => $request->t_libro, 'tipo' => 'libro', 'created_at' => $fecha]);
        if ($request->t_uniforme > 0) ControlCuadre::create(['monto' => $request->t_uniforme, 'tipo' => 'uniforme', 'created_at' => $fecha]);
        if ($request->t_actividad > 0) ControlCuadre::create(['monto' => $request->t_actividad, 'tipo' => 'actividad', 'created_at' => $fecha]);
        if ($request->t_extra > 0) ControlCuadre::create(['monto' => $request->t_extra, 'tipo' => 'extra', 'created_at' => $fecha]);
    }

    // TODO: realizar que las BoletasControlCuadre se adjunte el dia de ayer


}
