<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Articulo;
use App\Models\Compra;
use App\Models\CompraProveedores;
use App\Models\FacturaProveedor;
use App\Models\Proveedor;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class CompraController extends Controller
{
    // retorna la vista para comprar articulos
    public function index(Request $request)
    {

        $articulos = DB::table('articulos as art')
            ->join('categoria as cat', 'art.categoria_id', '=', 'cat.id')
            ->select('cat.nombre as nomCat', 'cat.tipo', 'art.nombre', 'art.cod_barras', 'art.descripcion', 'art.p_venta', 'art.p_costo', 'art.stock', 'art.img', 'art.id')
            ->where('art.deleted_at', null)
            ->get();

        return view('admin.articulos.compras', ['articulos' => $articulos, 'vis' => true]);
    }

    public function store(Request $request)
    {
        $articulo = $this->guardar($request);
        return back()->with(['info' => "Factura $articulo, registrada con Exito", 'color' => 'success']);
    }

    // retorna la vista de historial
    public function shows(Request $request)
    {
        $show = false;
        $historias = null;
        if ($request->fin && $request->inicio) {
            $show = true;
            $historias = DB::table('compra_articulos as ca')
                ->join('articulos as art', 'ca.articulo_id', '=', 'art.id')
                ->join('users as use', 'ca.user_id', '=', 'use.id')
                ->select('art.nombre', 'art.descripcion', 'art.img', 'ca.id as idCom', 'ca.factura', 'ca.cantidad', 'ca.fecha', 'art.id', 'ca.user_id', 'use.name')
                ->whereBetween('ca.created_at', [$request->inicio, $request->fin])
                ->orderBy('ca.id', 'DESC')
                ->get();
        }

        return view('admin.articulos.historialCompras', ['articlos' => $historias, 'show' => $show]);
    }




    public function report(Request $request)
    {
        $historias = DB::table('compra_articulos as ca')
            ->join('articulos as art', 'ca.articulo_id', '=', 'art.id')
            ->join('users as user', 'ca.user_id', '=', 'user.id')
            ->select(
                'art.nombre',
                'art.descripcion',
                'art.img',
                'ca.id as idCom',
                'ca.factura',
                'ca.cantidad',
                'ca.fecha',
                'art.id',
                'user.name as userName',
            )
            ->whereBetween('ca.created_at', [$request->inicio, $request->fin])
            ->orderBy('ca.id', 'DESC')
            ->get();
        return view('admin.reports.articulos.comprasHistorial', ['historial' => $historias]);
    }
}
