<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\BoletasControlCuadre;
use App\Models\ControlCuadre;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Response;
use Illuminate\Support\Facades\Storage;

class ControlCuadreController extends Controller
{

    public function show($tipo)
    {
        $cuadre = ControlCuadre::whereDate('created_at', date('Y-m-d-'))->where('tipo', $tipo)->first();
        if (!$cuadre) return back()->with(['info' => 'No Existen Datos de control de Cuadre para ' . $tipo, 'color' => 'danger']);
        $boletas = BoletasControlCuadre::cuadre($cuadre->id)->get();
        // dd($boletas);
        return view('admin.cuadrecontrol.show', compact('cuadre', 'boletas'));
    }

    public function store_boleta(Request $request, ControlCuadre $control)
    {
        if ($request->hasFile('foto')) {
            $boleta = new BoletasControlCuadre();
            $file = $request->file('foto');
            $nombre = time() . $file->getClientOriginalName();
            $file->move(storage_path() . '/app/public/boletas', $control->tipo . '_' . $nombre);
            $boleta->foto =   $control->tipo . '_' . $nombre;
            $boleta->controlcuadre_id = $request->cuadre_id;
            $boleta->valor = $request->valor;
            $boleta->referencia = $request->referencia;
            $boleta->concepto = $request->concepto;
            $boleta->acept = 'no';
            $boleta->save();
            return back()->with(['info' => 'boleta guardada con exito', 'color' => 'success']);
        } else {
            return back()->with(['info' => 'la foto no se cargo y no se guardo ', 'color' => 'danger']);
        }
    }

    public function delete_boleta(BoletasControlCuadre $boleta)
    {
        // ELIMINAMOS EL ARCHIVO DE LA FOTO
        Storage::disk('public')->delete('boletas/' . $boleta->foto);
        // eliminar boleta
        $boleta->delete();
        return back()->with(['info' => 'Boleta eliminada ', 'color' => 'success']);
    }

    public function acept_boleta(Request $request)
    {
        $boleta = BoletasControlCuadre::find($request->boleta);
        $boleta->acept = 'SI';
        $boleta->save();
        return Response::json([
            'request' => $request->all(),
            'boleta' => true
        ]);
    }

    public function controlCuadreNotBoletas($dia, $tipo)
    {
        $cuadre = ControlCuadre::whereDate('created_at', $dia)->where('tipo', $tipo)->first();
        $boletas = BoletasControlCuadre::cuadre($cuadre->id)->get();
        // dd($boletas);
        return view('admin.cuadrecontrol.shownotCuadre', compact('cuadre', 'boletas', 'dia'));
    }

    public function storeOldAbono(Request $request, ControlCuadre $control)
    {
        if ($request->hasFile('foto')) {
            $boleta = new BoletasControlCuadre();
            $file = $request->file('foto');
            $nombre = time() . $file->getClientOriginalName();
            $file->move(storage_path() . '/app/public/boletas', $control->tipo . '_' . $nombre);
            $boleta->foto =   $control->tipo . '_' . $nombre;
            $boleta->controlcuadre_id = $request->cuadre_id;
            $boleta->valor = $request->valor;
            $boleta->referencia = $request->referencia;
            $boleta->concepto = $request->concepto;
            $boleta->acept = 'no';
            $boleta->created_at = $request->created_at . ' ' .date('h:i:s');
            $boleta->save();
            return back()->with(['info' => 'boleta guardada con exito', 'color' => 'success']);
        } else {
            return back()->with(['info' => 'la foto no se cargo y no se guardo ', 'color' => 'danger']);
        }
    }

    public function getAbonosNotAcept($dia)
    {

        $boletas = BoletasControlCuadre::where('acept', 'no')->whereDate('created_at', $dia)->get();
        return view('admin.cuadrecontrol.shownotCuadrelist', compact('boletas', 'dia'));
    }

    function reports() {
        return view('admin.cuadrecontrol.report');
    }

    function getBoletas(Request $request) {
        $data = BoletasControlCuadre::whereBetween('created_at', [$request->inicio, $request->fin])->get();
        return view('admin.reports.caja.cuadreControl', compact('data'));
    }
}
