<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AbonoActividad;
use App\Models\Abonos;
use App\Models\AbonoWeb;
use App\Models\Actividad;
use App\Models\Bolsa;
use App\Models\Bus;
use App\Models\Convenio;
use App\Models\DescuentoEstudiatens;
use App\Models\DeudaBus;
use App\Models\DeudaColegiatura;
use App\Models\DeudaExtra;
use App\Models\DeudaInscripcion;
use App\Models\Estudiante;
use App\Models\Factura;
use App\Models\Grado;
use App\Models\Libros;
use App\Models\ListaDeUtiles;
use App\Models\Papeleria;
use App\Models\Promocion;
use App\Models\PromocionEstudiante;
use App\Models\RecordInformativo;
use App\Models\Uniforme;
use App\Models\VentaBus;
use App\Models\VentaLibros;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class EstudianteController extends Controller
{

   public function index()
   {
      $estudiantes = Estudiante::all();

      return view('admin.estudiantes.index', ['data' => $estudiantes]);
   }

   public function edit($id)
   {

      $grado = Grado::all();
      $estudiante = DB::table('estudiantes as es')
         ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
         ->select('gr.nombre as grado', 'gr.id as grado_id', 'gr.nivel as nivel', 'es.*', 'gr.seccion')
         ->where('es.id', $id)
         ->first();
      $promo = Promocion::all();
      $pe = PromocionEstudiante::where('estudiante_id', $id)->get();
      return view('admin.estudiantes.update', ['data' => $estudiante, 'grados' => $grado, 'promos' => $promo, 'pe' => $pe]);
   }

   public function update(Request $request, $id)
   {
      Estudiante::findOrFail($id)->update($request->all());


      if (isset($request->promocion)) {

         for ($i = 0; $i < count($request->promocion); $i++) {
            $p = new PromocionEstudiante();
            $p->estudiante_id = $id;
            $p->promocion_id = $request->promocion[$i];
            $p->save();
         }
      }

      if ($request->hasFile('foto')) {
         $estudiante = Estudiante::findOrFail($id);
         $file = $request->file('foto');
         $nombre = time() . $file->getClientOriginalName();
         $file->move(storage_path() . '/app/public/estudiantes', $nombre);
         $estudiante->foto = $nombre;
         // dd($estudiante);
         $estudiante->save();
      }

      return back()->with(['info' => 'ESTUDIANTE Actualizado con Exito', 'color' => 'success']);
   }

   public function show($id)
   {

      $estudiante = DB::table('estudiantes as es')
         ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
         ->select('gr.nombre as grado', 'gr.nivel as nivel', 'es.*', 'gr.id as grado_id')
         ->where('es.id', $id)
         ->first();

      $edad = Carbon::parse($estudiante->fecha_nacimiento)->age;

      $uniformes = Uniforme::all();
      $bus = Bus::all();
      $bolsa = Bolsa::all();
      $record = $this->allrecords($id);
      $actividades = Actividad::where('grado_id', $estudiante->grado_id)->get();

      // para ventas / adquisiciones
      $venta_uniformes = $this->ventas_uniformes($id);
      $venta_bolsas = $this->ventas_bolsas($id);
      $deuda_entradas = $this->deudas_extra($id);
      $busAsignado = $this->busAsignado($id);
      $venta_actividades = $this->venta_actividad($id);

      // para deudas
      $deudaBus = $this->deudaDeBuses($id);
      $abonos_dia = Abonos::where('estudiante_id', $id)->orderby('id', 'desc')->get();

      // para descuentos
      $descuentos = $this->descuento($id);

      // nueva esturctura para ver las deudas
      $bus_Asignado = $this->busAsignado($id);
      $deuda_Bus = $this->deudaDeBuses($id);
      $venta_uniformes2 = DB::table('venta_uniformes as ven')
         ->join('uniformes as uni', 'ven.uniforme_id', '=', 'uni.id')
         ->select('uni.nombre', 'uni.talla', 'uni.description', 'ven.cantidad', 'ven.descuento', 'ven.total', 'uni.p_venta')
         ->where('estudiante_id', $id)
         ->where('ven.deleted_at', null)
         ->get();


      $venta_bolsas = DB::table('venta_bolsas as ven')
         ->join('bolsas as bol', 'ven.bolsa_id', '=', 'bol.id')
         ->select('ven.cantidad', 'ven.descuento', 'ven.total', 'bol.nombre', 'bol.p_venta', 'bol.decripcion', 'ven.factura_id', 'ven.created_at', 'ven.id')
         ->where('estudiante_id', $id)
         ->where('ven.deleted_at', null)
         ->get();


      $deuda_extras = $this->deudas_extra($id);
      $venta_actividades = $this->venta_actividad($id);
      $deuda_colegiaturas = DeudaColegiatura::where('estudiante_id', $id)->first();
      $deuda_inscripcion = DeudaInscripcion::where('estudiante_id', $id)->first();

      $abonos = $this->getAbonos($id);

      $t_col = 0;
      $t_bus = 0;
      $t_bol = 0;
      $t_uni = 0;
      $t_act = 0;
      $t_ext = 0;
      $t_libros = 0;

      if ($deuda_Bus != null) {
         $t_bus =  $deuda_Bus->mes1 + $deuda_Bus->mes2 + $deuda_Bus->mes3 + $deuda_Bus->mes4 + $deuda_Bus->mes5 + $deuda_Bus->mes6 + $deuda_Bus->mes7 + $deuda_Bus->mes8 + $deuda_Bus->mes9 + $deuda_Bus->mes10;
      }

      $t_col += $deuda_colegiaturas->mes1 + $deuda_colegiaturas->mes2 + $deuda_colegiaturas->mes3 + $deuda_colegiaturas->mes4 + $deuda_colegiaturas->mes5 + $deuda_colegiaturas->mes6 + $deuda_colegiaturas->mes7 + $deuda_colegiaturas->mes8 + $deuda_colegiaturas->mes9 + $deuda_colegiaturas->mes10;


      $listas = ListaDeUtiles::groupby('codigo')->get();

      foreach ($venta_bolsas as $vol) {
         $t_bol += $vol->total;
      }

      foreach ($venta_uniformes as $uni) {
         $t_uni += $uni->total;
      }

      foreach ($venta_actividades as $act) {
         $t_act += $act->total;
      }

      foreach ($deuda_extras as $value) {
         $t_ext += $value->valor;
      }
      $estudainte2 = Estudiante::findOrFail($id);
      $convenio = Convenio::where('estudiante_id', $id)->get();
      $pe = PromocionEstudiante::where('estudiante_id', $id)->get();

      // dd($venta_bolsas);

      // para lo nuevo de actividad
      $t_abono_acti = 0;
      $abonos_acti = AbonoActividad::where('estudiante_id', $id)->get();
      foreach ($abonos_acti as $v) {
         $t_abono_acti += $v->valor;
      }

      $papeleria = Papeleria::where('estudiante_id', $id)->first();

      $libros = Libros::all();
      $venta_libros = VentaLibros::where('estudiante_id', $id)->get();

      foreach ($venta_libros as $v_l) {
         $t_libros += $v_l->total;
      }

      return view('admin.estudiantes.show', [
         'abonos_dia' => $abonos_dia,
         'abonos' => $abonos,
         'actividades' => $actividades,
         'bus_asignado' => $bus_Asignado,
         'busAsignados' => $busAsignado,
         'buses' => $bus,
         'convenio' => $convenio,
         'data' => $estudiante,
         'descuentos' => $descuentos,
         'deu_extra' => $deuda_entradas,
         'deuda_bus' => $deuda_Bus,
         'deuda_bus' => $deudaBus,
         'deuda_colegiatura' => $deuda_colegiaturas,
         'deuda_inscripcion' => $deuda_inscripcion,
         'deudas_extras' => $deuda_extras,
         'edad' => $edad,
         'estudiante' => $estudainte2,
         'libros' => $libros,
         'listas' => $listas,
      
         'records' => $record,
         'total_actividad' => $t_act,
         'total_bolsa' => $t_bol,
         'total_bus' => $t_bus,
         'total_colegiatura' => $t_col,
         'total_ext' => $t_ext,
         'total_libros' => $t_libros,
         'total_uniforme' => $t_uni,
         'uniformes' => $uniformes,
         'utiles' => $bolsa,
         'v_bolsas' => $venta_bolsas,
         'v_uniformes' => $venta_uniformes,
         'venta_actividades' => $venta_actividades,
         'venta_bolsas' => $venta_bolsas,
         'venta_uniformes' => $venta_uniformes2,
         'venta_libros' => $venta_libros,
         'pe' => $pe,
         't_abono_acti' => $t_abono_acti,
         'abonos_acti' => $abonos_acti,
         'papeleria' => $papeleria
      ]);
   }

   public function grados(Request $request)
   {

      $grado = null;

      if ($request->grado_id) {
         $grado = $request->grado_id;
      }



      $estudiantes =
         DB::table('estudiantes as es')
         ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
         ->select('gr.nombre as grado', 'gr.nivel as nivel', 'es.*')
         ->where('gr.id', $grado)
         ->where('es.deleted_at', null)
         ->get();

      $grados = Grado::all();
      return view('admin.estudiantes.grados', ['data' => $estudiantes, 'grados' => $grados]);
   }

   // retorna todos los "records" de un estudiante
   public function allrecords($id)
   {
      return RecordInformativo::where('estudiante_id', $id)->get();
   }


   // retorna la vista de dotos los deudores
   public function deudoresView()
   {
      $estudiantes = DB::table('estudiantes as es')
         ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
         ->join('encargados as en', 'es.encargado_id', '=', 'en.id')
         ->select('gr.nombre as grado', 'gr.nivel as nivel', 'gr.seccion',  'es.*', 'en.nombre1 as encargado', 'en.telefono1', 'en.telefono2', 'en.nombre2', 'en.telefono3', 'en.telefono4')
         ->where('es.deleted_at', null)
         ->whereColumn('es.deuda', '>', 'es.abono')
         ->orderBy('es.nombre', 'asc')
         ->get();

      return view('admin.estudiantes.index', ['data' => $estudiantes]);
   }


   // --------------------------
   // ventas --- retorna la finforemacion de "ventas"
   // --------------------------

   public function ventas_uniformes($id)
   {
      return DB::table('venta_uniformes as v_uni')
         ->join('uniformes as uni', 'v_uni.uniforme_id', '=', 'uni.id')
         ->select('uni.*', 'v_uni.factura_id', 'v_uni.factura_id', 'v_uni.cantidad as cantidaComprada', 'v_uni.descuento', 'v_uni.total', 'v_uni.id as idventa', 'v_uni.created_at as fechaventa')
         ->where('v_uni.estudiante_id', $id)
         ->where('v_uni.deleted_at', null)
         ->orderBy('v_uni.id', 'DESC')
         ->get();
   }

   public function ventas_bolsas($id)
   {
      return  DB::table('venta_bolsas as v_bolsa')
         ->join('bolsas as bol', 'v_bolsa.bolsa_id', '=', 'bol.id')
         ->select('bol.*', 'v_bolsa.factura_id', 'v_bolsa.factura_id', 'v_bolsa.cantidad as cantidaComprada', 'v_bolsa.descuento', 'v_bolsa.total', 'v_bolsa.created_at as fechaventa', 'v_bolsa.id as idventa')
         ->where('v_bolsa.estudiante_id', $id)
         ->where('v_bolsa.deleted_at', null)
         ->orderBy('v_bolsa.id', 'DESC')

         ->get();
   }

   public function deudas_extra($id)
   {
      return DeudaExtra::where('estudiante_id', $id)->get();
   }

   public function busAsignado($id)
   {
      return VentaBus::where('estudiante_id', $id)->first();
   }

   // para ver el total de buses por cada mes (deuda de buses)
   public function deudaDeBuses($id)
   {
      return DeudaBus::where('estudiante_id', $id)->first();
   }

   public function venta_actividad($id)
   {
      return  DB::table('venta_actividads as vn')
         ->join('actividades as ac', 'vn.actividad_id', '=', 'ac.id')
         ->select('vn.total', 'vn.estudiante_id', 'vn.description', 'ac.nombre', 'ac.descripcion', 'ac.costo', 'ac.fecha', 'vn.id')
         ->where('estudiante_id', $id)
         ->orderBy('vn.id', 'desc')
         ->get();
   }

   // -------------
   // - PARA ABONOS DE DEUDAS
   // -------------

   // retorna la vista para poder ver las deudas de un estudiante
   public function deudasAll($id)
   {
      $estudiante = Estudiante::findOrFail($id);
      $bus_Asignado = $this->busAsignado($id);
      $deuda_Bus = $this->deudaDeBuses($id);
      $venta_uniformes = DB::table('venta_uniformes as ven')
         ->join('uniformes as uni', 'ven.uniforme_id', '=', 'uni.id')
         ->select('uni.nombre', 'uni.talla', 'uni.description', 'ven.cantidad', 'ven.descuento', 'ven.total', 'uni.p_venta')
         ->where('estudiante_id', $id)
         ->where('ven.deleted_at', null)
         ->get();


      $venta_bolsas = DB::table('venta_bolsas as ven')
         ->join('bolsas as bol', 'ven.bolsa_id', '=', 'bol.id')
         ->select('ven.cantidad', 'ven.descuento', 'ven.total', 'bol.nombre', 'bol.p_venta', 'bol.decripcion', 'ven.factura_id', 'ven.created_at', 'ven.id')
         ->where('estudiante_id', $id)
         ->where('ven.deleted_at', null)
         ->get();


      $deuda_extras = $this->deudas_extra($id);
      $venta_actividades = $this->venta_actividad($id);
      $deuda_colegiaturas = DeudaColegiatura::where('estudiante_id', $id)->first();
      $deuda_inscripcion = DeudaInscripcion::where('estudiante_id', $id)->first();
      $venta_libros = VentaLibros::where('estudiante_id', $id)->get();


      $abonos = $this->getAbonos($id);



      $t_col = 0;
      $t_bus = 0;
      $t_bol = 0;
      $t_uni = 0;
      $t_act = 0;
      $t_ext = 0;
      $t_libros = 0;


      $descuentos = $this->descuento($id);

      if ($deuda_Bus != null) {
         $t_bus =  $deuda_Bus->mes1 + $deuda_Bus->mes2 + $deuda_Bus->mes3 + $deuda_Bus->mes4 + $deuda_Bus->mes5 + $deuda_Bus->mes6 + $deuda_Bus->mes7 + $deuda_Bus->mes8 + $deuda_Bus->mes9 + $deuda_Bus->mes10;
      }

      $t_col += $deuda_colegiaturas->mes1 + $deuda_colegiaturas->mes2 + $deuda_colegiaturas->mes3 + $deuda_colegiaturas->mes4 + $deuda_colegiaturas->mes5 + $deuda_colegiaturas->mes6 + $deuda_colegiaturas->mes7 + $deuda_colegiaturas->mes8 + $deuda_colegiaturas->mes9 + $deuda_colegiaturas->mes10;

      foreach ($venta_bolsas as $vol) {
         $t_bol += $vol->total;
      }

      foreach ($venta_uniformes as $uni) {
         $t_uni += $uni->total;
      }

      foreach ($venta_actividades as $act) {
         $t_act += $act->total;
      }

      foreach ($deuda_extras as $value) {
         $t_ext += $value->valor;
      }

      foreach ($venta_libros as $uni) {
         $t_libros += $uni->total;
      }

      return view('admin.estudiantes.deudas', [
         'estudiante' => $estudiante,
         'bus_asignado' => $bus_Asignado,
         'venta_uniformes' => $venta_uniformes,
         'venta_bolsas' => $venta_bolsas,
         'deudas_extras' => $deuda_extras,
         'venta_libros' => $venta_libros,
         'venta_actividades' => $venta_actividades,
         'deuda_colegiatura' => $deuda_colegiaturas,
         'deuda_inscripcion' => $deuda_inscripcion,
         'deuda_bus' => $deuda_Bus,
         'abonos' => $abonos,
         'total_bolsa' => $t_bol,
         'total_libros' => $t_libros,
         'total_uniforme' => $t_uni,
         'total_actividad' => $t_act,
         'total_ext' => $t_ext,
         'total_colegiatura' => $t_col,
         'total_bus' => $t_bus,
         'descuentos' => $descuentos
      ]);
   }


   public function getAbonos($id)
   {
      $abonos = array();

      $inscripcion = $this->getTipeAbonos($id, 'INSCRIPCION');
      $colegiatura = $this->getTipeAbonos($id, 'COLEGIATURA');
      $bus = $this->getTipeAbonos($id, 'BUS');
      $bolsa = $this->getTipeAbonos($id, 'BOLSA DE UTILES');
      $uniformes = $this->getTipeAbonos($id, 'UNIFORME');
      $actividades = $this->getTipeAbonos($id, 'ACTIVIDADES');
      $deuda_extra = $this->getTipeAbonos($id, 'DEUDA EXTRA');
      $libros = $this->getTipeAbonos($id, 'LIBROS');
      array_push($abonos, $inscripcion, $colegiatura, $bus, $bolsa, $uniformes, $actividades, $deuda_extra,  $libros);
      // dd($abonos);
      return $abonos;
   }

   public function getTipeAbonos($id, $tipo)
   {

      return Abonos::where('estudiante_id', $id)
         ->where('estado', 'PAGADO')
         ->where('abonoa', $tipo)
         ->orderBy('id', 'asc')
         ->get();
   }

   // retorna los abonos agrupados por dia
   public function recibosDay($id)
   {
      return  Abonos::where('estudiante_id', $id)
         ->groupBy('factura_id')->get();
   }

   // retorna el resumend detodas las deudas realizadas y abono realizados de un estudiante
   public function deuda_resumen($id)
   {
      $estudiante = Estudiante::findOrFail($id);
      $bus_Asignado = $this->busAsignado($id);
      $deuda_Bus = $this->deudaDeBuses($id);
      $venta_uniformes = DB::table('venta_uniformes as ven')
         ->join('uniformes as uni', 'ven.uniforme_id', '=', 'uni.id')
         ->select('uni.nombre', 'uni.talla', 'uni.description', 'ven.cantidad', 'ven.descuento', 'ven.total', 'uni.p_venta')
         ->where('estudiante_id', $id)
         ->where('ven.deleted_at', null)
         ->get();


      $venta_bolsas = DB::table('venta_bolsas as ven')
         ->join('bolsas as bol', 'ven.bolsa_id', '=', 'bol.id')
         ->select('ven.cantidad', 'ven.descuento', 'ven.total', 'bol.nombre', 'bol.p_venta', 'bol.decripcion', 'ven.factura_id', 'ven.created_at', 'ven.id')
         ->where('estudiante_id', $id)
         ->where('ven.deleted_at', null)
         ->get();


      $deuda_extras = $this->deudas_extra($id);
      $venta_actividades = $this->venta_actividad($id);
      $deuda_colegiaturas = DeudaColegiatura::where('estudiante_id', $id)->first();
      $deuda_inscripcion = DeudaInscripcion::where('estudiante_id', $id)->first();

      $abonos = $this->getAbonos($id);

      $t_col = 0;
      $t_bus = 0;
      $t_bol = 0;
      $t_uni = 0;
      $t_act = 0;
      $t_ext = 0;

      $descuentos = $this->descuento($id);

      if ($deuda_Bus != null) {
         $t_bus =  $deuda_Bus->mes1 + $deuda_Bus->mes2 + $deuda_Bus->mes3 + $deuda_Bus->mes4 + $deuda_Bus->mes5 + $deuda_Bus->mes6 + $deuda_Bus->mes7 + $deuda_Bus->mes8 + $deuda_Bus->mes9 + $deuda_Bus->mes10;
      }


      $t_col += $deuda_colegiaturas->mes1 + $deuda_colegiaturas->mes2 + $deuda_colegiaturas->mes3 + $deuda_colegiaturas->mes4 + $deuda_colegiaturas->mes5 + $deuda_colegiaturas->mes6 + $deuda_colegiaturas->mes7 + $deuda_colegiaturas->mes8 + $deuda_colegiaturas->mes9 + $deuda_colegiaturas->mes10;

      foreach ($venta_bolsas as $vol) {
         $t_bol += $vol->total;
      }

      foreach ($venta_uniformes as $uni) {
         $t_uni += $uni->total;
      }

      foreach ($venta_actividades as $act) {
         $t_act += $act->total;
      }

      foreach ($deuda_extras as $value) {
         $t_ext += $value->valor;
      }

      return view('admin.reports.estudiantes.resumendeuda', [
         'estudiante' => $estudiante,
         'bus_asignado' => $bus_Asignado,
         'venta_uniformes' => $venta_uniformes,
         'venta_bolsas' => $venta_bolsas,
         'deudas_extras' => $deuda_extras,
         'venta_actividades' => $venta_actividades,
         'deuda_colegiatura' => $deuda_colegiaturas,
         'deuda_inscripcion' => $deuda_inscripcion,
         'deuda_bus' => $deuda_Bus,
         'abonos' => $abonos,
         'total_bolsa' => $t_bol,
         'total_uniforme' => $t_uni,
         'total_actividad' => $t_act,
         'total_ext' => $t_ext,
         'total_colegiatura' => $t_col,
         'total_bus' => $t_bus,
         'descuentos' => $descuentos
      ]);
   }

   // -----------------
   //   VISTAS PARA LA GENERACION DE REPORTES
   // ----------------

   // retorna la vista para generar reportes
   public function reports()
   {
      $grados = Grado::all();
      return view('admin.estudiantes.reports',   compact('grados'));
   }

   // retorna a todos los estudiantes inscritos
   public function allEstudiante()
   {
      $estudiantes =
         DB::table('estudiantes as es')
         ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
         ->select('gr.nombre as grado', 'gr.nivel as nivel', 'gr.seccion',  'es.*')
         ->where('es.deleted_at', null)
         ->orderBy('es.nombre', 'asc')
         ->get();
      return view('admin.reports.estudiantes.estudianteall', ['data' => $estudiantes]);
   }

   // retorna a todos los estudiantes deudores
   public function alldeudores()
   {
      $estudiantes = DB::table('estudiantes as es')
         ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
         ->select('gr.nombre as grado', 'gr.nivel as nivel', 'gr.seccion',  'es.*')
         ->where('es.deleted_at', null)
         ->whereColumn('es.deuda', '>', 'es.abono')
         ->orderBy('es.nombre', 'asc')
         ->get();

      $total = 0;

      foreach ($estudiantes as $estu) {

         $total += ($estu->deuda - $estu->abono);
      }

      return view('admin.reports.estudiantes.alldeudores', ['data' => $estudiantes, 'total' => $total]);
   }

   // retorna a los estudiantes por niveles
   public function allnivel(Request $request)
   {
      $estudiantes = DB::table('estudiantes as es')
         ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
         ->select('gr.nombre as grado', 'gr.nivel as nivel', 'gr.seccion',  'es.*')
         ->where('es.deleted_at', null)
         ->where('nivel', $request->nivel)
         ->orderBy('es.nombre', 'asc')
         ->get();

      return view('admin.reports.estudiantes.estudianteall', ['data' => $estudiantes]);
   }

   // retorna a todos los estudiante cumpleaneros
   public function cumpleaneros(Request $request)
   {

      $estu = DB::table('estudiantes as es')
         ->whereMonth('fecha_nacimiento', $request->mes)
         ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
         ->select('gr.nombre as grado', 'gr.nivel as nivel', 'gr.seccion',  'es.*')
         ->orderBy('es.fecha_nacimiento', 'asc')
         ->where('es.deleted_at', null)
         ->get();
      return view('admin.reports.estudiantes.estudianteall', ['data' => $estu]);
   }

   // retorna los deudores por Rango de Dinero
   public function rangodeDeudas(Request $request)
   {
      $estu = DB::table('estudiantes as estu')
         ->join('grados as gr', 'estu.grado_id', '=', 'gr.id')
         ->join('encargados as en', 'estu.encargado_id', '=', 'en.id')
         ->select('estu.nombre', 'estu.jornada', DB::raw('(estu.deuda - estu.abono) as deuda'), 'gr.nombre as grado', 'gr.seccion', 'gr.nivel', 'gr.id as grado_id', 'estu.id', 'estu.cui', 'en.nombre1 as encargado', 'en.telefono1', 'en.telefono2', 'en.telefono3', 'en.telefono4')
         ->where(DB::raw('(estu.deuda - estu.abono)'), '>=', $request->minimo)
         ->where(DB::raw('(estu.deuda - estu.abono)'), '<=', $request->maximo)
         ->whereColumn('deuda', '>', 'abono')
         ->orderBy('estu.nombre', 'asc')

         ->get();

      $total = 0;
      foreach ($estu as $estud) {
         $total += ($estud->deuda);
      }

      return view('admin.reports.grados.deudores', ['data' => $estu, 'name' => "REPORTE DEUDORES EN UN RANGO DE $request->minimo A $request->maximo", 'total' => $total]);
   }

   // retorna los descuentos de un estudiante
   public function descuento($id)
   {
      return DescuentoEstudiatens::where('estudiante_id', $id)->get();
   }


   // =========================================
   // 	 	 	 RETORNA LA VISTA PARA PODER GENERERAR EL CONTRATAO DE SERVICIOSAD
   // ========================================= 

   public function contratoServicios($id)
   {
      $estudiante = DB::table('estudiantes as es')
         ->join('encargados as en', 'es.encargado_id', '=', 'en.id')
         ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
         ->select('es.nombre as estudiante', 'es.cui', 'es.fecha_nacimiento', 'es.jornada', 'es.colegiatura', 'es.inscripcion', 'gr.nombre as grado', 'gr.seccion', 'gr.nivel', 'en.*')
         ->where('es.id', $id)
         ->first();

      return view('admin.reports.estudiantes.contrato', ['data' => $estudiante]);
   }

   // retorna todos los abonos que ha realizado en web
   public function abonos_web($id)
   {
      $abonos = AbonoWeb::where('estudiante_id', $id)->get();

      return view('admin.reports.abono.abono_web_estudiante', ['data' => $abonos]);
   }

   // elimina un estudiante
   public function deleteEstudiante($id)
   {
      Estudiante::find($id)->delete();
      return redirect()->route('estudiante.index')->with(['Estudiante Retirado Con Exito']);
   }

   // obtiene a los estudiantes retirados
   public function getRetirados()
   {
      $data =
         DB::table('estudiantes as es')
         ->join('grados as gr', 'es.grado_id', '=', 'gr.id')
         ->join('encargados as en', 'es.encargado_id', '=', 'en.id')
         ->select('gr.nombre as grado', 'gr.nivel as nivel', 'gr.seccion',  'es.*', 'en.nombre1 as encargado', 'en.telefono1', 'en.telefono2', 'en.nombre2', 'en.telefono3', 'en.telefono4')
         ->where('es.deleted_at', '!=', null)
         ->get();

      $titulo = 'RETIRADOS';

      return view('admin.reports.estudiantes.estudianteall', compact('data', 'titulo'));
   }

   public function actualizarCole($estu_id)
   {
      $estudiante = Estudiante::find($estu_id);
      $colegiatura = DeudaColegiatura::where('estudiante_id', $estudiante->id)->get();
      $inscripcion = DeudaInscripcion::where('estudiante_id', $estudiante->id)->get();
      $bus = DeudaBus::where('estudiante_id', $estudiante->id)->get();

      return view('admin.estudiantes.deudasUpdate', compact('estudiante', 'colegiatura', 'inscripcion', 'bus'));
   }

   public function updateColegiatura(DeudaColegiatura $deuda, Request $request)
   {
      $deuda->update($request->all());
      return back()->with(['info' => 'Tabla Actualizada', 'color' => 'success']);
   }

   public function updateInscripcion(DeudaInscripcion $deuda, Request $request)
   {
      $deuda->update($request->all());
      $estu = Estudiante::find($deuda->estudiante_id);
      $estu->inscripcion = $deuda->deuda;
      $estu->save();
      return back()->with(['info' => 'Tabla Actualizada', 'color' => 'success']);
   }


   // para actualizar la deuda de los buses de un estudiante
   public function updateDeudaDeBus(DeudaBus $bus, Request $request)
   {
      $bus->update($request->all());
      return back()->with(['info' => 'Deuda Actualizada', 'color' => 'success']);
   }

   function resumendedeudas($estu_id)
   {


      $abonos = Abonos::where('estudiante_id', $estu_id)->first();
      $estu = Estudiante::find($estu_id);

      $deuda_Bus = $this->deudaDeBuses($estu->id);
      $venta_uniformes = DB::table('venta_uniformes as ven')
         ->join('uniformes as uni', 'ven.uniforme_id', '=', 'uni.id')
         ->select('uni.nombre', 'uni.talla', 'uni.description', 'ven.cantidad', 'ven.descuento', 'ven.total', 'uni.p_venta')
         ->where('estudiante_id', $estu->id)
         ->where('ven.deleted_at', null)
         ->get();

      $venta_bolsas = DB::table('venta_bolsas as ven')
         ->join('bolsas as bol', 'ven.bolsa_id', '=', 'bol.id')
         ->select('ven.cantidad', 'ven.descuento', 'ven.total', 'bol.nombre', 'bol.p_venta', 'bol.decripcion', 'ven.factura_id', 'ven.created_at', 'ven.id')
         ->where('estudiante_id', $estu->id)
         ->where('ven.deleted_at', null)
         ->get();

      $deuda_extras = $this->deudas_extra($estu->id);
      $venta_actividades = $this->venta_actividad($estu->id);
      $deuda_colegiaturas = DeudaColegiatura::where('estudiante_id', $estu->id)->first();
      $deuda_inscripcion = DeudaInscripcion::where('estudiante_id', $estu->id)->first();
      $ab_actividad = AbonoActividad::select(DB::raw('sum(valor) as total'))->where('estudiante_id', $estu->id)->first()->total;

      $t_col = 0;
      $t_bus = 0;
      $t_bol = 0;
      $t_uni = 0;
      $t_act = 0;
      $t_ext = 0;

      if ($deuda_Bus != null) {
         $t_bus =  $deuda_Bus->mes1 + $deuda_Bus->mes2 + $deuda_Bus->mes3 + $deuda_Bus->mes4 + $deuda_Bus->mes5 + $deuda_Bus->mes6 + $deuda_Bus->mes7 + $deuda_Bus->mes8 + $deuda_Bus->mes9 + $deuda_Bus->mes10;
      }

      $t_col += $deuda_colegiaturas->mes1 + $deuda_colegiaturas->mes2 + $deuda_colegiaturas->mes3 + $deuda_colegiaturas->mes4 + $deuda_colegiaturas->mes5 + $deuda_colegiaturas->mes6 + $deuda_colegiaturas->mes7 + $deuda_colegiaturas->mes8 + $deuda_colegiaturas->mes9 + $deuda_colegiaturas->mes10;

      foreach ($venta_bolsas as $vol) {
         $t_bol += $vol->total;
      }

      foreach ($venta_uniformes as $uni) {
         $t_uni += $uni->total;
      }

      foreach ($venta_actividades as $act) {
         $t_act += $act->total;
      }

      foreach ($deuda_extras as $value) {
         $t_ext += $value->valor;
      }

      $descuentos = $this->descuento($estu->id);
      $abonos2 = $this->getAbonos($estu->id);

      return view('admin.reports.abono.recibo_sida', [
         'abonos' => $abonos,
         'estudiante' => $estu,
         'abonos2' => $abonos2,
         'total_bolsa' => $t_bol,
         'total_uniforme' => $t_uni,
         'total_actividad' => $t_act,
         'total_ext' => $t_ext,
         'total_colegiatura' => $t_col,
         'descuentos' => $descuentos,
         'total_bus' => $t_bus,
         'venta_actividades' => $venta_actividades,
         'deuda_colegiatura' => $deuda_colegiaturas,
         'deuda_inscripcion' => $deuda_inscripcion,
         'ab_actividad' => $ab_actividad
      ]);
   }
}
