<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Estudiante;
use App\Models\Grado;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class GradoController extends Controller
{

    public function index()
    {
        return view('admin.grados.index', ['grados' => Grado::all()]);
    }

    public function create()
    {
        return view('admin.grados.create');
    }

    public function store(Request $request)
    {
        Grado::create($request->all());
        return back()->with(['info' => 'grado registrado con exito', 'color' => 'success']);
    }

    public function show($id)
    {
        return view('admin.grados.show', ['grado' => Grado::findOrFail($id)]);
    }

    public function delete($id)
    {
        Grado::findOrFail($id)->delete();
        return back()->with(['info' => 'grado eliminado con exito', 'color' => 'success']);
    }

    public function update(Request $request, $id)
    {
        Grado::findOrFail($id)->update($request->all());
        $grado = Grado::find($id);

        $estu = Estudiante::where('grado_id', $id)->get();
        foreach ($estu as $e) {

            $e->colegiatura = $grado->colegiatura;
            $e->inscripcion = $grado->costo_inscripcion;
            $e->save();
        }


        return back()->with(['info' => 'grado actualizado con exito', 'color' => 'success']);
    }

    // retorn al avista para realizar los reportes
    public function reportes()
    {
        $grado = Grado::all();
        return view('admin.grados.reportes', ['grados' => $grado]);
    }

    // retorna el reporte de todos los grados
    public function allgrados()
    {
        return view('admin.reports.grados.all', ['grados' => Grado::all()]);
    }

    // retorna el reporte de estudiantes por grados
    public function estudiantesDeGrados(Request $request)
    {
        $estu = Estudiante::where('grado_id', $request->grado_id)->orderBy('nombre', 'asc')->get();


        $grado = Grado::findOrFail($request->grado_id);

        return view('admin.reports.grados.estudiantegrado', ['data' => $estu, 'grado' => $grado]);
    }

    // retorna el reporte de los deudores por grado
    public function alldeures(Request $request)
    {


        if ($request->grado_id === 'TODOS') {
            $estu = Estudiante::orderBy('nombre', 'asc')->get();
            $grado = Grado::all();
            // calcula el total de todas las deudas
            $total = 0;
            foreach ($estu as $estud) {
                $total += ($estud->deuda);
            }

            return view('admin.reports.grados.deudores', ['data' => $estu, 'name' => 'REPORTE DE TODOS LOS DEUDORES', 'total' => $total]);
        }
        $estu = Estudiante::where('grado_id', $request->grado_id)->orderBy('nombre', 'asc')->get();
        $grado = Grado::find($request->grado_id);
        // calcula el total de todas las deudas
        $total = 0;
        foreach ($estu as $estud) {
            $total += ($estud->deuda);
        }

        return view('admin.reports.grados.deudores', ['data' => $estu, 'name' => 'reporte estudiantes del grado: ' . $grado->nombre . ' ' . $grado->nivel . ' Seccion: "' . $grado->seccion . '"', 'total' => $total]);
    }

    // retorna el reporte de los deudores
    public function deudores(Request $request)
    {
        $estu = DB::table('estudiantes as estu')
            ->join('grados as gr', 'estu.grado_id', '=', 'gr.id')
            ->join('encargados as en', 'estu.encargado_id', '=', 'en.id')
            ->select('estu.nombre', 'estu.jornada', DB::raw('(estu.deuda - estu.abono) as deuda'), 'gr.nombre as grado', 'gr.seccion', 'gr.nivel', 'gr.id as grado_id', 'estu.id', 'estu.cui', 'en.nombre1 as encargado', 'en.telefono1', 'en.telefono2', 'en.telefono3', 'en.telefono4')
            ->whereColumn('deuda', '>', 'abono')
            ->where('estu.deleted_at', null)
            ->orderBy('es.fecha_nacimiento', 'asc')
            ->get();


        $total = 0;
        foreach ($estu as $estud) {
            $total += ($estud->deuda);
        }


        return view('admin.reports.grados.deudores', ['data' => $estu, 'name' => 'reporte de todos los deudores', 'total' => $total]);
    }

    public function getDeudoreForTipo(Request $request)
    {
        $estu = [];
        $grado = [];

        if ($request->grado_id[0] !== 'TODOS') {
            # code...
            for ($i = 0; $i < count($request->grado_id); $i++) {
                array_push($grado, Grado::find($request->grado_id[$i]));
            }
        }

        if ($request->grado_id[0] === 'TODOS') {
            $au = Grado::all();
            foreach ($au as $g) {
                array_push($grado, $g);
            }

            array_push($estu, Estudiante::orderBy('nombre', 'asc')->get());
        }

        for ($i = 0; $i < count($request->grado_id); $i++) {
            array_push($estu, Estudiante::where('grado_id', $request->grado_id[$i])->orderBy('nombre', 'asc')->get());
        }

        $tipo = $request->abonoa;
        return view('admin.reports.grados.deudorestipo', compact('estu', 'tipo', 'grado'));
    }

    public function getPadreToGrado(Request $request)
    {

        $data = Estudiante::where('grado_id', $request->grado_id)->orderBy('nombre', 'asc')->get();
        $grado = Grado::find($request->grado_id);

        return view('admin.reports.estudiantes.gradoPadre', compact('data', 'grado'));
    }
}
