<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Actividad;
use App\Models\Bolsa;
use App\Models\Bus;
use App\Models\DeudaBus;
use App\Models\DeudaColegiatura;
use App\Models\DeudaExtra;
use App\Models\Encargado;
use App\Models\Estudiante;
use App\Models\Grado;
use App\Models\MobiliarioEquipo;
use App\Models\NotaTrabajador;
use App\Models\Uniforme;
use App\Models\User;
use App\Models\Vehiculo;
use App\Models\VentaBus;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class HomeController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {

        $user = User::count();
        $estu = Estudiante::count();
        $enca = Encargado::count();
        $grado = Grado::count();

        $uni = Uniforme::count();
        $bus = Bus::count();
        $utiles = Bolsa::count();
        $mobi = MobiliarioEquipo::count();
        $acti = Actividad::count();
        $vehi = Vehiculo::count();
        $notas = $this->getNotasTraba();
        $actividadesProximas = $this->proximasActividades();

        $min_bolsa = $this->minStockBolsa();
        $min_uni = $this->minStockUniformes();
        if (date('d') === '01' && date('Y') === config('app.cliclo')) {
            $this->asignarColegiatura();
            // dd('Entro');
            $this->asignar_deuda_bus();
        }

        if (date('d') === '08' && date('Y') === config('app.cliclo')) {
            // $this->asignarMoradeColegiatura();
        }
        $t_caja = $this->listMovimiento('e');
        $t_gasto = $this->listMovimiento('s');
        $abono = $this->getAbonos(date('Y-m-d'));

        return view('admin.home.home', [
            'user' => $user, 'estu' => $estu, 'enca' => $enca, 'grado' => $grado, 'uni' => $uni, 'bus' => $bus, 'utiles' => $utiles, 'mobi' => $mobi, 'acti' => $acti, 'vehi' => $vehi, 'min_bolsa' => $min_bolsa, 'min_uni' => $min_uni, 'notas' => $notas, 'proximas_actividades' => $actividadesProximas,
            // para cuadre
            't_caja' => $t_caja, 't_gasto' => $t_gasto, 'abonos' => $abono
        ]);
    }

    // retorna las notas a los trabajadores
    public function getNotasTraba()
    {
        $fecha1 = now()->toDateString();
        $fecha2 = now()->addDays(2)->toDateString();
        return  NotaTrabajador::whereBetween('fecha', [$fecha1, $fecha2])
            ->get();
    }

    // retorna las proximas actividades a realizar
    public function proximasActividades()
    {
        $fecha1 = now()->toDateString();
        $fecha2 = now()->addDays(25)->toDateString();

        return DB::table('actividades as act')
            ->join('grados as gr', 'act.grado_id', '=', 'gr.id')
            ->select('act.id', 'act.nombre', 'act.descripcion', 'act.costo', 'act.fecha', 'gr.nombre as grado', 'gr.seccion')
            ->whereBetween('fecha', [$fecha1, $fecha2])
            ->where('act.deleted_at', null)
            ->get();
    }

    // asigna las deuas de colegiatura
    public function asignarColegiatura()
    {

        $estudiante = Estudiante::all();

        foreach ($estudiante as $est) {
            $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
            if (($deu->mes1 <= 0) && (date('m') === '01')) {
                $deu->mes1 = $est->colegiatura;
                $deu->estado1 = ($deu->estado1 === 'CANCELADO' || $deu->estado1 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
            }
            if (($deu->mes2 <= 0) && (date('m') === '02')) {
                $deu->mes2 = $est->colegiatura;
                $deu->estado2 = ($deu->estado2 === 'CANCELADO' || $deu->estado2 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
            }
            if (($deu->mes3 <= 0) && (date('m') === '03')) {
                $deu->mes3 = $est->colegiatura;
                $deu->estado3 = ($deu->estado3 === 'CANCELADO' || $deu->estado3 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
            }
            if (($deu->mes4 <= 0)  &&  (date('m') === '04')) {
                // dd('Entro');
                $deu->mes4 = $est->colegiatura;
                $deu->estado4 = ($deu->estado4 === 'CANCELADO' || $deu->estado4 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
            }
            if (($deu->mes5 <= 0) && (date('m') === '05')) {
                $deu->mes5 = $est->colegiatura;
                $deu->estado5 = ($deu->estado5 === 'CANCELADO' || $deu->estado5 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
            }
            if (($deu->mes6 <= 0) && (date('m') === '06')) {
                $deu->mes6 = $est->colegiatura;
                $deu->estado6 = ($deu->estado6 === 'CANCELADO' || $deu->estado6 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
            }
            if (($deu->mes7 <= 0) && (date('m') === '07')) {
                $deu->mes7 = $est->colegiatura;
                $deu->estado7 = ($deu->estado7 === 'CANCELADO' || $deu->estado7 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
            }
            if (($deu->mes8 <= 0) && (date('m') === '08')) {
                $deu->mes8 = $est->colegiatura;
                $deu->estado8 = ($deu->estado8 === 'CANCELADO' || $deu->estado8 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
            }
            if (($deu->mes9 <= 0) && (date('m') === '09')) {
                $deu->mes9 = $est->colegiatura;
                $deu->estado9 = ($deu->estado9 === 'CANCELADO' || $deu->estado9 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
            }
            if (($deu->mes10 <= 0) && (date('m') === '10')) {
                $deu->mes10 = $est->colegiatura;

                $deu->estado10 = ($deu->estado10 === 'CANCELADO' || $deu->estado10 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
            }
            $deu->save();
        }

        return;
    }


    // asigna las deudas de colegiatura por mes
    function asignarColegiaturasFormMes(Request $request)
    {
        $estudiante = Estudiante::all();

        switch ($request->mes) {
            case '01':
                foreach ($estudiante as $est) {
                    $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
                    if (($deu->mes1 <= 0)) {
                        $deu->mes1 = $est->colegiatura;
                        $deu->estado1 = ($deu->estado1 === 'CANCELADO' || $deu->estado1 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                        $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
                    }
                    $deu->save();
                }
                break;
            case '02':
                foreach ($estudiante as $est) {
                    $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
                    if (($deu->mes2 <= 0)) {
                        $deu->mes2 = $est->colegiatura;
                        $deu->estado2 = ($deu->estado2 === 'CANCELADO' || $deu->estado2 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                        $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
                    }
                    $deu->save();
                }
                break;
            case '03':
                foreach ($estudiante as $est) {
                    $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
                    if (($deu->mes3 <= 0)) {
                        $deu->mes3 = $est->colegiatura;
                        $deu->estado3 = ($deu->estado3 === 'CANCELADO' || $deu->estado3 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                        $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
                    }
                    $deu->save();
                }
                break;
            case '04':
                foreach ($estudiante as $est) {
                    $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
                    if (($deu->mes4 <= 0)) {
                        // dd('Entro');
                        $deu->mes4 = $est->colegiatura;
                        $deu->estado4 = ($deu->estado4 === 'CANCELADO' || $deu->estado4 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                        $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
                    }
                    $deu->save();
                }
                break;
            case '05':
                foreach ($estudiante as $est) {
                    $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
                    if (($deu->mes5 <= 0)) {
                        $deu->mes5 = $est->colegiatura;
                        $deu->estado5 = ($deu->estado5 === 'CANCELADO' || $deu->estado5 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                        $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
                    }
                    $deu->save();
                }
                break;
            case '06':
                foreach ($estudiante as $est) {
                    $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
                    if (($deu->mes6 <= 0)) {
                        $deu->mes6 = $est->colegiatura;
                        $deu->estado6 = ($deu->estado6 === 'CANCELADO' || $deu->estado6 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                        $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
                    }
                    $deu->save();
                }
                break;
            case '07':
                foreach ($estudiante as $est) {
                    $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
                    if (($deu->mes7 <= 0)) {
                        $deu->mes7 = $est->colegiatura;
                        $deu->estado7 = ($deu->estado7 === 'CANCELADO' || $deu->estado7 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                        $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
                    }
                    $deu->save();
                }
                break;
            case '08':
                foreach ($estudiante as $est) {
                    $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
                    if (($deu->mes8 <= 0)) {
                        $deu->mes8 = $est->colegiatura;
                        $deu->estado8 = ($deu->estado8 === 'CANCELADO' || $deu->estado8 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                        $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
                    }
                    $deu->save();
                }
                break;
            case '09':
                foreach ($estudiante as $est) {
                    $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
                    if (($deu->mes9 <= 0)) {
                        $deu->mes9 = $est->colegiatura;
                        $deu->estado9 = ($deu->estado9 === 'CANCELADO' || $deu->estado9 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                        $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
                    }
                    $deu->save();
                }
                break;
            case '10':
                foreach ($estudiante as $est) {
                    $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
                    if (($deu->mes10 <= 0)) {
                        $deu->mes10 = $est->colegiatura;

                        $deu->estado10 = ($deu->estado10 === 'CANCELADO' || $deu->estado10 == NULL) ? 'CANCELADO' : 'ASIGNADO';
                        $this->asignarDeudaEstudiante($est->id, $est->colegiatura);
                    }
                    $deu->save();
                }
                break;

            default:
                # code...
                break;
        }
        return redirect()->route('home')->with(['info' => 'colegiatura Asignada', 'color' => 'success']);
    }

    // asigna mora de colegiatura
    public function asignarMoradeColegiatura()
    {

        // veluar ciclo actual

        $estudiante = Estudiante::all();

        foreach ($estudiante as $est) {
            $deu = DeudaColegiatura::where('estudiante_id', $est->id)->first();
            if ($deu->estado2 === 'ASIGNADO') {

                $this->asignarDeudaEstudiante($est->id, 10);
                $this->asignarMoraColegiatura($est->id, 10, 'FEBRERO');
            }
            if ($deu->estado3 === 'ASIGNADO') {

                $this->asignarDeudaEstudiante($est->id, 10);
                $this->asignarMoraColegiatura($est->id, 10, 'MARZO');
            }
            if ($deu->estado4 === 'ASIGNADO') {
                $this->asignarDeudaEstudiante($est->id, 10);
                $this->asignarMoraColegiatura($est->id, 10, 'ABRIL');
            }
            if ($deu->estado5 === 'ASIGNADO') {
                $this->asignarDeudaEstudiante($est->id, 10);
                $this->asignarMoraColegiatura($est->id, 10, 'MAYO');
            }
            if ($deu->estado6 === 'ASIGNADO') {
                $this->asignarDeudaEstudiante($est->id, 10);
                $this->asignarMoraColegiatura($est->id, 10, 'JUNIO');
            }
            if ($deu->estado7 === 'ASIGNADO') {
                $this->asignarDeudaEstudiante($est->id, 10);
                $this->asignarMoraColegiatura($est->id, 10, 'JULIO');
            }
            if ($deu->estado8 === 'ASIGNADO') {
                $this->asignarDeudaEstudiante($est->id, 10);
                $this->asignarMoraColegiatura($est->id, 10, 'AGOSTO');
            }
            if ($deu->estado9 === 'ASIGNADO') {
                $this->asignarDeudaEstudiante($est->id, 10);
                $this->asignarMoraColegiatura($est->id, 10, 'SEPTIEMBRE');
            }
            if ($deu->estado10 === 'ASIGNADO') {
                $this->asignarDeudaEstudiante($est->id, 10);
                $this->asignarMoraColegiatura($est->id, 10, 'OCTUBRE');
            }
            $deu->save();
        }

        return;
    }

    // asigna la deudan a un estudiante
    public function asignarDeudaEstudiante($id, $deuda)
    {
        $estudiante = Estudiante::find($id);
        $estudiante->deuda += $deuda;
        return  $estudiante->save();
    }

    // asigna la mora como una deuda extra a cada estudiante
    public function asignarMoraColegiatura($id, $valor, $mes)
    {
        // evaluar ciclo
        $deuda = new DeudaExtra();
        $deuda->estudiante_id = $id;
        $deuda->valor = $valor;
        $deuda->descripcion = 'MORA DEL MES ' . $mes;
        $deuda->save();
    }

    // retona el minimo de stock de los utiles
    public function minStockBolsa()
    {
        return DB::table('bolsas')->whereColumn('stock', '<=', 'min_stock')->get();
    }

    // retona el minimo de stock de los uniformes
    public function minStockUniformes()
    {
        return DB::table('uniformes')->whereColumn('stock', '<=', 'minio_stock')->get();
    }

    // retorna los datos de cajaChica
    public function listMovimiento($tipo)
    {
        $movimiento = DB::table('cajas')
            ->where('operacion', $tipo)
            ->whereDate('fecha', date('Y-m-d'))
            ->get();

        $total = 0;
        foreach ($movimiento as $data) {
            $total += $data->valor;
        }
        return $total;
    }

    // retorna los abonos para el cuadre de caja
    public function getAbonos($date)
    {

        $abonos = array();
        $efectivo = $this->getTiposAbonos('EFECTIVO', $date);
        $visa = $this->getTiposAbonos('VISA', $date);
        $cheque = $this->getTiposAbonos('CHEQUE', $date);
        $transeferencia = $this->getTiposAbonos('TRANSFERENCIA', $date);
        $deposito = $this->getTiposAbonos('DEPOSITO', $date);
        $otro = $this->getTiposAbonos('OTRO', $date);

        $t_efectivo = 0;
        $t_visa = 0;
        $t_cheque = 0;
        $t_transeferencia = 0;
        $t_deposito = 0;
        $t_otro = 0;

        foreach ($efectivo as $data) {
            $t_efectivo += $data->valor;
        }
        foreach ($visa as $data) {
            $t_visa += $data->valor;
        }
        foreach ($cheque as $data) {
            $t_cheque += $data->valor;
        }
        foreach ($transeferencia as $data) {
            $t_transeferencia += $data->valor;
        }
        foreach ($deposito as $data) {
            $t_deposito += $data->valor;
        }
        foreach ($otro as $data) {
            $t_otro += $data->valor;
        }

        array_push($abonos, $t_efectivo, $t_visa, $t_cheque, $t_transeferencia, $t_deposito, $t_otro);


        return $abonos;
    }

    // retorna los tipos de abonos
    // retorna los abonos por tipo y por fecha
    public function getTiposAbonos($tipo, $date)
    {
        return DB::table('abonos')
            ->select('*')
            ->where('tipo', $tipo)
            ->whereDate('created_at', $date)
            ->where('deleted_at', '=', null)
            ->get();
    }

    public function asignar_deuda_bus()
    {
        $estudiante = Estudiante::all();


        foreach ($estudiante as $estu) {

            $ven = VentaBus::where('estudiante_id', $estu->id)->first();
            $deuda = DeudaBus::where('estudiante_id', $estu->id)->first();


            if (isset($ven->pago_mensual)) {

                // dd($deuda);
                $pag = $ven->pago_mensual;



                if (date('Y') === config('app.cliclo')) {
                    if (date('m') === '01' && $ven->estado1 === 'ASIGNADO' && $deuda->mes1 === 0) {
                        $deuda->mes1 = $pag;
                        $deuda->save();
                        dd('entro');
                        $this->asignarDeudaEstudiante($estu->id, $pag);
                    }

                    if (date('m') === '02' && $ven->estado2 === 'ASIGNADO' && $deuda->mes2 == 0) {
                        $deuda->mes2 = $pag;
                        $deuda->save();
                        $this->asignarDeudaEstudiante($estu->id, $pag);
                    }

                    if (date('m') === '03' && $ven->estado3 === 'ASIGNADO' && $deuda->mes3 == 0) {
                        $deuda->mes3 = $pag;
                        $deuda->save();
                        $this->asignarDeudaEstudiante($estu->id, $pag);
                    }

                    if (date('m') === '04' && $ven->estado4 === 'ASIGNADO' && $deuda->mes4 == 0) {
                        $deuda->mes4 = $pag;
                        $deuda->save();
                        $this->asignarDeudaEstudiante($estu->id, $pag);
                    }

                    if (date('m') === '05' && $ven->estado5 === 'ASIGNADO' && $deuda->mes5 == 0) {
                        $deuda->mes5 = $pag;
                        $deuda->save();
                        $this->asignarDeudaEstudiante($estu->id, $pag);
                    }

                    if (date('m') === '06' && $ven->estado6 === 'ASIGNADO' && $deuda->mes6 == 0) {
                        $deuda->mes6 = $pag;
                        $deuda->save();
                        $this->asignarDeudaEstudiante($estu->id, $pag);
                    }

                    if (date('m') === '07' && $ven->estado7 === 'ASIGNADO' && $deuda->mes7 == 0) {
                        $deuda->mes7 = $pag;
                        $deuda->save();
                        $this->asignarDeudaEstudiante($estu->id, $pag);
                    }

                    if (date('m') === '08' && $ven->estado8 === 'ASIGNADO' && $deuda->mes8 == 0) {
                        $deuda->mes8 = $pag;
                        $deuda->save();
                        $this->asignarDeudaEstudiante($estu->id, $pag);
                    }

                    if (date('m') === '09' && $ven->estado9 === 'ASIGNADO' && $deuda->mes9 == 0) {
                        $deuda->mes9 = $pag;
                        $deuda->save();
                        $this->asignarDeudaEstudiante($estu->id, $pag);
                    }

                    if (date('m') === '10' && $ven->estado10 === 'ASIGNADO' && $deuda->mes10 == 0) {
                        $deuda->mes10 = $pag;
                        $deuda->save();
                        $this->asignarDeudaEstudiante($estu->id, $pag);
                    }

                    // if (date('m') === '11' && $ven->estado11 === 'ASIGNADO' && $deuda->mes11 == 0) {
                    //     $deuda->mes11 = $pag;
                    //     $deuda->save();
                    //     $this->asignarDeudaEstudiante($estu->id, $pag);
                    // }

                    // if (date('m') === '12' && $ven->estado12 === 'ASIGNADO' && $deuda->mes12 == 0) {
                    //     $deuda->mes12 = $pag;
                    //     $deuda->save();
                    //     $this->asignarDeudaEstudiante($estu->id, $pag);
                    // }
                }
            }
        }
    }
}
