<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Insumos;
use Illuminate\Http\Request;

class InsumoController extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $insumos = Insumos::all();
        return view('admin.insumos.index', compact('insumos'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.insumos.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'nombre' => 'required|string|max:255',
            'cantidad' => 'required|integer',
            'p_venta' => 'required|numeric',
        ]);

        Insumos::create($validatedData);

        return redirect()->route('insumos.create')->with(['info' => 'Insumo creado con exito', 'color' => 'success']);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Insumo  $insumo
     * @return \Illuminate\Http\Response
     */
    public function show(Insumos $insumo)
    {
        return view('admin.insumos.show', compact('insumo'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Insumo  $insumo
     * @return \Illuminate\Http\Response
     */
    public function edit(Insumos $insumo)
    {
        return view('admin.insumos.edit', compact('insumo'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Insumo  $insumo
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Insumos $insumo)
    {
        $validatedData = $request->validate([
            'nombre' => 'sometimes|required|string|max:255',
            'cantidad' => 'sometimes|required|integer',
            'p_venta' => 'sometimes|required|numeric',
        ]);

        $insumo->update($validatedData);

        return redirect()->route('insumos.index')->with(['info' => 'Insumo creado con exito', 'color' => 'success']);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Insumo  $insumo
     * @return \Illuminate\Http\Response
     */
    public function destroy(Insumos $insumo)
    {
        $insumo->delete();

        return redirect()->route('insumos.index')->with(['info' => 'Insumo creado con exito', 'color' => 'success']);
    }
}
