<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\CompraLibros;
use App\Models\Estudiante;
use App\Models\Factura;
use App\Models\Libros;
use App\Models\VentaLibros;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class LibrosController extends Controller
{
    public function index()
    {
        return view('admin.libros.index', ['bolsas' => Libros::all()]);
    }

    public function create()
    {
        return view('admin.libros.create');
    }

    public function store(Request $request)
    {
        Libros::create($request->all());
        return back()->with(['info' => 'libro registrado con exito', 'color' => 'success']);
    }

    public function show($id)
    {
        return view('admin.libros.show', ['bolsa' => Libros::findOrFail($id)]);
    }

    public function delete($id)
    {
        Libros::findOrFail($id)->delete();
        return back()->with(['info' => 'libro eliminado con exito', 'color' => 'success']);
    }

    public function update(Request $request, $id)
    {
        Libros::findOrFail($id)->update($request->all());
        return back()->with(['info' => 'libro actualizado con exito', 'color' => 'success']);
    }


    // ---------------------------
    // VENTA DE BOLSAS
    // ---------------------------
    public function storeVenta(Request $request)
    {
        $factura = $this->guardarFactura($request);

        for ($i = 0; $i < count($request->id_bolsas); $i++) {
            $venta = new VentaLibros();
            $venta->libro_id = $request->id_bolsas[$i];
            $venta->estudiante_id = $request->estudiante_id;
            $venta->factura_id = $factura->id;
            $venta->cantidad = $request->cantidad_bolsa[$i];
            $venta->descuento = $request->descuento_bolsa[$i];
            $venta->total = $request->subtotal_bolsa[$i];
            $venta->save();
            $bol = Libros::find($request->id_bolsas[$i]);
            $bol->stock -= $request->cantidad_bolsa[$i];
            $bol->save();
        }

        
        // asiganar deuda a estudiante 
        $this->asignarDeudaEstudiante($request->estudiante_id, $factura->total);
        return back()->with(['info' => 'libro de utiles vendidos con exito', 'color' => 'success']);
    }

    public function ventaRecibo($recibo, $estudiante)
    {
        $factura = DB::table('facturas as fac')
            ->join('estudiantes as estu', 'fac.estudiante_id', '=', 'estu.id')
            ->select('estu.nombre as estudiante', 'estu.cui', 'estu.id', 'fac.*')
            ->where('fac.id', $recibo)
            ->first();

        $uniformes = DB::table('venta_libros as v_bolsa')
            ->join('libros as bol', 'v_bolsa.libro_id', '=', 'bol.id')
            ->select('bol.*', 'v_bolsa.factura_id', 'v_bolsa.factura_id', 'v_bolsa.cantidad as cantidaComprada', 'v_bolsa.descuento', 'v_bolsa.total')
            ->where('v_bolsa.estudiante_id', $estudiante)
            ->where('v_bolsa.factura_id', $recibo)
            ->get();

        return view('admin.reports.libros.recibo', ['factura' => $factura, 'uniformes' => $uniformes]);
    }

    public function guardarFactura(Request $request)
    {
        // para facturas 
        $total_cancelar = 0;
        $total_des = 0;
        // end facturas
        $factura = new Factura();
        $factura->estudiante_id = $request->estudiante_id;
        $factura->descripcion = $request->descripcion;
        for ($i = 0; $i < count($request->id_bolsas); $i++) {
            $total_cancelar  += $request->bolsa_pventa_table[$i];
            $total_des += $request->descuento_bolsa[$i];
        }

        $factura->total_cancelar = $total_cancelar;
        $factura->total_des = $total_des;
        $factura->total = $request->totalventa_bolsa;

        $factura->save();
        return $factura;
    }

    // asigna la deudan a un estudiante
    public function asignarDeudaEstudiante($id, $deuda)
    {
        $estudiante = Estudiante::find($id);
        $estudiante->deuda += $deuda;
        return  $estudiante->save();
    }

    // elimina una venta de uniforme y remueve la deuda del estudiante
    public function deleteVenta($id)
    {
        $venta = VentaLibros::find($id);
        $estudiante = Estudiante::find($venta->estudiante_id);
        // cambiamos el total de las deudas en los estudiantes
        $estudiante->deuda -= $venta->total;
        $bolsa = Libros::find($venta->bolsa_id);
        $bolsa->stock += $venta->cantidad;
        $bolsa->save();
        $venta->delete();
        $estudiante->save();

        return back()->with(['info' => 'venta de libro elimida con exito', 'color' => 'success']);
    }

    // retorna la vista para los Reportes
    public function reports()
    {
        $bolsa = Libros::all();
        $recibos = CompraLibros::groupby('recibo')->get();
        return view('admin.libros.reportes', compact('bolsa', 'recibos'));
    }

    // retorna el reporte de toso las articulos registrados
    public function allBolsa()
    {
        $bol = Libros::all();
        return view('admin.reports.libros.all', ['bolsas' => $bol, 'visible' => true, 'nombre' => 'libro registradas']);
    }

    // retona el reporte de los articulos con minimo de stock
    public function minStockBolsa()
    {
        $bolsa = DB::table('libros')->whereColumn('stock', '<=', 'min_stock')->get();

        return view('admin.reports.libros.all', ['visible' => false, 'bolsas' => $bolsa, 'nombre' => 'libro con minimo de stock']);
    }

    // retorna el reporte para control de existencias
    public function controldeExisteicias()
    {
        $bol = Libros::all();
        return view('admin.reports.libros.all', ['bolsas' => $bol, 'visible' => false, 'nombre' => 'libro registradas']);
    }

    // retorna el reported de las ventas de uniformes por mes
    public function reportVentas(Request $request)
    {

        $ventas =  DB::table('venta_libros as ven')
            ->join('libros as bol', 'ven.libro_id', '=', 'bol.id')
            ->select('ven.cantidad', 'ven.descuento', 'ven.factura_id', 'ven.total', 'ven.created_at', 'bol.*')
            ->whereBetween('ven.created_at', [$request->inicio, $request->fin])
            ->where('ven.deleted_at', null)
            ->get();

        $t_sin = 0;
        $t_con = 0;
        $t_des = 0;
        $t_gan = 0;

        return view('admin.reports.libros.ventas', ['ventas' => $ventas, 'mes' => $request->mes, 't_gan' => $t_gan, 't_des' => $t_des, 't_con' => $t_con, 't_sin' => $t_sin]);
    }




    // retorn el historial de compra de bolsa de utiles
    public function reporte_historial(Request $request)
    {
        $articulos =
            DB::table('compra_libros as com')
            ->join('libros as bol', 'com.libro_id', '=', 'bol.id')
            ->join('users as u', 'com.user_id', '=', 'u.id')
            ->select('bol.*', 'com.*', 'u.*', 'com.id as compraId', 'com.created_at as f_compra',)
            ->whereBetween('com.created_at', [$request->inicio, $request->fin])
            ->get();
        return view('admin.reports.libros.historial', compact('articulos'));
    }

    public function reporte_historial_agrupado(Request $request)
    {
        $articulos =
            DB::table('compra_libros as com')
            ->join('libros as bol', 'com.libro_id', '=', 'bol.id')
            ->join('users as u', 'com.user_id', '=', 'u.id')
            ->select('bol.*', 'com.*', 'u.*', 'com.id as compraId',  DB::raw('Sum(com.cantidad) as ctcompra'), 'com.created_at as f_compra',)
            ->whereBetween('com.created_at', [$request->inicio, $request->fin])
            ->groupBy('bol.id')
            ->get();


        return view('admin.reports.libros.compraunidas', compact('articulos'));
    }


    public function ventas_agrupados_detallado(Request $request)
    {
        $ventas = [];
        for ($i = 0; $i < count($request->bolsa_id); $i++) {
            # code...
            $venta =  DB::table('venta_libros as ven')
                ->join('libros as bol', 'ven.libro_id', '=', 'bol.id')
                ->select('ven.cantidad', 'ven.descuento', 'ven.factura_id', 'ven.total', 'ven.created_at', 'bol.*')
                ->whereBetween('ven.created_at', [$request->inicio, $request->fin])
                ->where('bol.id', $request->bolsa_id[$i])
                ->where('ven.deleted_at', null)
                ->get();
            array_push($ventas, $venta);
        }

        $bolsa = Libros::find($request->bolsa_id);
        $t_sin = 0;
        $t_con = 0;
        $t_des = 0;
        $t_gan = 0;
        return view('admin.reports.libros.ventasDetalladas', ['ventas' => $ventas, 'mes' => $request->mes, 't_gan' => $t_gan, 't_des' => $t_des, 't_con' => $t_con, 't_sin' => $t_sin,]);
    }

    public function ventas_agrupados(Request $request)
    {
        $bolsa = Libros::all();

        $inicio = $request->inicio;
        $fin = $request->fin;

        return view('admin.reports.libros.ventasAgrupadas', compact(
            'bolsa',
            'inicio',
            'fin',

        ));
    }

    public function getBolsaToReciboAndFecha(Request $request)
    {
        $compras = [];
        for ($i = 0; $i < count($request->bolsa_id); $i++) {
            $d = CompraLibros::where('recibo', $request->bolsa_id[$i])->whereBetween('f_compra', [$request->inicio, $request->fin])->get();
            array_push($compras, $d);
        }
        return view('admin.reports.libros.comprasreports', compact('compras'));
    }

    function listDB()
    {
        $bolsa = Libros::all();
        return view('admin.libros.listdb', compact('bolsa'));
    }

    function saveToDB(Request $request)
    {

        for ($i = 0; $i < count($request->id); $i++) {
            $u = Libros::find($request->id[$i]);
            $u->stock = $request->stock[$i];
            $u->fisico = $request->fisico[$i];
            $u->p_venta = $request->p_ventas[$i];
            $u->save();
        }
        return back()->with(['info' =>  'DATOS ACTUALIZADOS', 'color'   => 'success']);
    }

    function code_print($id)
    {
        $articulo = Libros::find($id);
        return view('admin.reports.libros.code', ['articulo' => $articulo]);
    }
}
