<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\HorasExtras;
use App\Models\Planilla;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class PlanillaController extends Controller
{

    public function index()
    {
        return view('admin.planillas.index', ['data' => Planilla::all()]);
    }

    public function create()
    {
        return view('admin.planillas.create');
    }

    public function store(Request $request)
    {

        $plan =  Planilla::create($request->all());
        $p = Planilla::find($plan->id);
        if ($request->hasFile('cv')) {
            $file = $request->file('cv');
            $nombre = time() . $file->getClientOriginalName();
            $file->move(storage_path() . '/app/public/planilla', $nombre);
            $p->cv = $nombre;
            // dd($estudiante);
            $p->save();
        }
        // dd();
        return back()->with(['info' => 'planilla mensual guardada con exito', 'color' => 'success']);
    }

    public function update(Request $request, $id)
    {
        Planilla::findOrFail($id)->update($request->all());
        return back()->with(['info' => 'planilla actualizada con exito', 'color' => 'success']);
    }

    public function show($id)
    {
        return view('admin.planillas.show', ['data' => Planilla::findOrFail($id)]);
    }

    public function delete($id)
    {
        Planilla::findOrFail($id)->delete();

        return back()->with(['info' => 'planilla eliminada con exito', 'color' => 'success']);
    }

    // retorna la vista para pago de horas extras
    public function horasExtras()
    {
        $data2 = DB::table('horas_extras as h')
            ->join('planillas as p', 'h.planilla_id', '=', 'p.id')
            ->select('h.*', 'p.nombre', 'p.asignacion')
            ->orderBy('h.id', 'desc')
            ->paginate(30);

        return view('admin.planillas.horasextras', ['data' => Planilla::all(), 'data2' => $data2]);
    }

    // guarda los datos de una hora extras
    public function saveHoraExtra(Request $request)
    {
        HorasExtras::create($request->all());
        return back()->with(['info' => 'hora extra asignada con exito', 'color' => 'success']);
    }

    public function deleteHorasExtras($id)
    {
        HorasExtras::findOrFail($id)->delete();

        return back()->with(['info' => 'planilla eliminada con exito', 'color' => 'success']);
    }

    // =========================================
    // 	 	 	 REPORETES
    // ========================================= 
    public function reportes()
    {
        return view('admin.planillas.reports');
    }

    // rotorna todos los colaboradores de planillas
    public function reportAllPla()
    {
        return view('admin.reports.planilla.all', ['data' => Planilla::all()]);
    }

    // retorna el gasto de horas HorasExtras filtradas por mes
    public function reportHorasMes(Request $request)
    {
        $data2 = DB::table('horas_extras as h')
            ->join('planillas as p', 'h.planilla_id', '=', 'p.id')
            ->select('h.*', 'p.nombre', 'p.asignacion')
            ->orderBy('h.id', 'desc')
            ->whereMonth('h.created_at', $request->mes)
            ->get();

        $total = 0;
        foreach ($data2 as $d) {
            $total += $d->numero * 10;
        }

        return view('admin.reports.planilla.horas', ['data2' => $data2, 'titulo' => 'horas extras del mes ' . $request->mes, 'total' => $total]);
    }

    // retorna el pago de horas extras
    public function reportHorasMesPalan(Request $request)
    {
        $data2 = DB::table('horas_extras as h')
            ->join('planillas as p', 'h.planilla_id', '=', 'p.id')
            ->select('h.*', 'p.nombre', 'p.asignacion')
            ->orderBy('h.id', 'desc')
            ->whereMonth('h.created_at', $request->mes)
            ->where('h.planilla_id', $request->planilla_id)
            ->get();

        $total = 0;
        foreach ($data2 as $d) {
            $total += $d->numero * 10;
        }

        return view('admin.reports.planilla.horas', ['data2' => $data2, 'titulo' => 'horas extras del mes ' . $request->mes, 'total' => $total]);
    }
}
