<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AbonoProveedor;
use App\Models\Actividad;
use App\Models\Bolsa;
use App\Models\CompraBolsaUtiles;
use App\Models\CompraUniformes;
use App\Models\Estudiante;
use App\Models\Grado;
use App\Models\Libros;
use App\Models\Uniforme;
use App\Models\VentaBolsa;
use App\Models\VentaUnidormeProfeso;
use App\Models\VentaUniforme;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class ReporteController extends Controller
{
    // =============================================
    // =============================================
    // PARA REPORTES MENSUALES O REPORTES DE VENTAS
    // =============================================
    // =============================================

    public function reportes_mensuales()
    {
        return view('admin.reportes.reportes_mensuales');
    }

    public function reporte_uniforme()
    {
        $uniformes = Uniforme::orderby('nombre', 'asc')->get();
        return view('admin.reports.reportes.mensuales.uniforme', compact('uniformes'));
    }

    public function reporte_bolsa()
    {
        $bolsa = Bolsa::all();
        return view('admin.reports.reportes.mensuales.bolsa', compact('bolsa'));
    }


    public function reporte_libros()
    {
        $bolsa = Libros::all();
        return view('admin.reports.reportes.mensuales.bolsa', compact('bolsa'));
    }

    public function reporte_colegiatura(Request $request)
    {
        $niveles = [];
        $preprimaria = Grado::where('nivel', 'PRE-PRIMARIA')->get();
        $primaria = Grado::where('nivel', 'PRIMARIA')->get();
        $basico = Grado::where('nivel', 'BASICO')->get();
        $diversificado = Grado::where('nivel', 'DIVERSIFICADO')->get();
        $basicopormadurez = Grado::where('nivel', 'BASICO POR MADUREZ')->get();
        $diversificadopormadurez = Grado::where('nivel', 'DIVERSIFICADO POR MADUREZ')->get();
        $mes = $request->mes;
        array_push(
            $niveles,
            $preprimaria,
            $primaria,
            $basico,
            $diversificado,
            $basicopormadurez,
            $diversificadopormadurez
        );

        return view('admin.reports.reportes.mensuales.colegiatura', compact('niveles', 'mes'));
    }

    public function reporte_actividad_tonivel(Request $request)
    {
        $visi = false;
        $nivel = $request->nivel;
        $act = null;
        $inicio = null;
        $final = null;
        if (isset($request->actividad_id)) {
            $visi = true;
            $act = $request->actividad_id;
            $inicio = $request->inicio;
            $final = $request->fin;
        }
        $actividad = Actividad::join('grados as gr', 'actividades.grado_id', '=', 'gr.id')
            ->select('gr.id', 'actividades.nombre as actividad_nombre', 'actividades.id as act_id', 'actividades.costo')
            ->groupby('actividades.nombre')
            ->where('gr.nivel',  'like', '%' . $request->nivel .  '%')
            ->get();
        $grados = Grado::where('nivel', '=', $request->nivel)->get();
        return view('admin.reports.reportes.mensuales.actividades', compact('actividad', 'grados', 'visi', 'nivel', 'act', 'inicio', 'final'));
    }

    // =============================================
    // =============================================
    // ==== PARA ANALISIS FINANCIERO=======
    // =============================================
    // =============================================

    public function reportes_analisis()
    {
        return view('admin.reportes.analisis');
    }

    public function analisis_uniformes(Request $request)
    {
        $compras = CompraUniformes::whereBetween('created_at', [$request->inicio, $request->fin])->groupby('recibo')->get();
        return view('admin.reports.reportes.analisis.uniformes', compact('compras'));
    }

    public function analisis_uniformes_bolsa(Request $request)
    {
        $inicio = $request->inicio;
        $fin = $request->fin;
        $c_uniformes = CompraUniformes::whereBetween('created_at', [$request->inicio, $request->fin])->get();
        $c_bolsa = CompraBolsaUtiles::whereBetween('created_at', [$request->inicio, $request->fin])->get();
        // abonos a proveedores
        $a_uniformes = AbonoProveedor::select(DB::raw('SUM(valor) as total'), 'tipo', 'descripcion', 'created_at')->where('tipo2', 'UNIFORME')->get();
        $a_bolsa = AbonoProveedor::select(DB::raw('SUM(valor) as total'), 'tipo', 'descripcion')->where('tipo2', 'BOLSA')->get();
        $v_uniformes = VentaUniforme::select(DB::raw('SUM(total) as total'), 'created_at')->whereBetween('created_at', [$request->inicio, $request->fin])->groupby('created_at')->get();
        $v_uniformes_prof = VentaUnidormeProfeso::select(DB::raw('SUM(total) as total'), 'created_at')->whereBetween('created_at', [$request->inicio, $request->fin])->groupby('created_at')->get();
        $v_bolsa = VentaBolsa::select(DB::raw('SUM(total) as total'), 'created_at')->whereBetween('created_at', [$request->inicio, $request->fin])->groupby('created_at')->get();
        return view('admin.reports.reportes.analisis.uniformes-libros', compact(
            'inicio',
            'fin',
            'c_uniformes',
            'c_bolsa',
            'a_uniformes',
            'a_bolsa',
            'v_uniformes',
            'v_uniformes_prof',
            'v_bolsa',

        ));
    }

    public function analisis_actividades(Request $request)
    {

        $actividad = Actividad::join('grados as gr', 'actividades.grado_id', '=', 'gr.id')
            ->select('gr.id', 'actividades.nombre as actividad_nombre', 'actividades.id as act_id', 'actividades.costo')
            ->groupby('actividades.nombre')
            ->where('gr.nivel',  'like', '%' . $request->nivel .  '%')
            ->whereBetween('actividades.created_at', [$request->inicio, $request->fin])
            ->get();
        $grados = Grado::where('nivel', '=', $request->nivel)->get();
        $inicio = $request->inicio;
        $fin = $request->fin;
        return view('admin.reports.reportes.analisis.actividades', compact('actividad', 'grados', 'inicio', 'fin'));
    }

    public function analisis_colegiatuera(Request $request)
    {
        $niveles = [];
        $preprimaria = Grado::where('nivel', 'PRE-PRIMARIA')->get();
        $primaria = Grado::where('nivel', 'PRIMARIA')->get();
        $basico = Grado::where('nivel', 'BASICO')->get();
        $diversificado = Grado::where('nivel', 'DIVERSIFICADO')->get();
        $basicopormadurez = Grado::where('nivel', 'BASICO POR MADUREZ')->get();
        $diversificadopormadurez = Grado::where('nivel', 'DIVERSIFICADO POR MADUREZ')->get();
        $mes = $request->mes;
        array_push(
            $niveles,
            $preprimaria,
            $primaria,
            $basico,
            $diversificado,
            $basicopormadurez,
            $diversificadopormadurez
        );
        return view('admin.reports.reportes.analisis.colegiaturas',  compact('niveles', 'mes'));
    }

    function esperadoColegiatura(Request $request)
    {
        $grados = Grado::all();
        return view('admin.reports.reportes.analisis.colegiaturasesperados', compact('grados'));
    }

    function realToGrados(Request $request) {
        $grados = Grado::all();
        
        return view('admin.reports.reportes.analisis.colegiaturasreales', compact('grados'));
    }
}
