<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\CompraUniformes;
use App\Models\DeudaUniforme;
use App\Models\Estudiante;
use App\Models\Factura;
use App\Models\Uniforme;
use App\Models\VentaUniforme;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class UniformeController extends Controller
{

    public function index()
    {
        return view('admin.uniformes.index', ['uniformes' => Uniforme::all()]);
    }

    public function create()
    {
        return view('admin.uniformes.create');
    }

    public function store(Request $request)
    {
        Uniforme::create($request->all());
        return back()->with(['info' => 'uniforme registrado con exito', 'color' => 'success']);
    }

    public function show($id)
    {
        return view('admin.uniformes.show', ['uniforme' => Uniforme::findOrFail($id)]);
    }

    public function delete($id)
    {
        Uniforme::findOrFail($id)->delete();
        return back()->with(['info' => 'Uniforme eliminado con exito', 'color' => 'success']);
    }

    public function update(Request $request, $id)
    {
        Uniforme::findOrFail($id)->update($request->all());
        return back()->with(['info' => 'Uniforme actualizado con exito', 'color' => 'success']);
    }

    // ---------------------------
    // VENTA DE UNIFORMES
    // ---------------------------

    public function storeVenta(Request $request)
    {

        $factura = $this->guardarFactura($request);
        for ($i = 0; $i < count($request->id_uniformes); $i++) {
            $venta = new VentaUniforme();
            $venta->uniforme_id = $request->id_uniformes[$i];
            $venta->estudiante_id = $request->estudiante_id;
            $venta->factura_id = $factura->id;
            $venta->cantidad = $request->cantidad_uniforme[$i];
            $venta->descuento = $request->descuento_uniforme[$i];
            $venta->total = $request->subtotal_uniforme[$i];
            $venta->save();
            // aqactualizar uniforme stock
            $uni = Uniforme::find($request->id_uniformes[$i]);
            $uni->stock -= $request->cantidad_uniforme[$i];
            $uni->save();
        }

        // para asignar deuda de uniformes de su tabla
        $deuda = DeudaUniforme::find($request->estudiante_id);
        if ($deuda) {
            $deuda->deuda +=  $factura->total;
            $deuda->save();
        } else {
            $deuda = new DeudaUniforme();
            $deuda->estudiante_id = $request->estudiante_id;
            $deuda->deuda = $factura->total;
            $deuda->save();
        }

        // asiganar deuda a estudiante 
        $this->asignarDeudaEstudiante($request->estudiante_id, $factura->total);
        return back()->with(['info' => 'uniformes vendidos con exito', 'color' => 'success']);
    }

    // guarda / registra una factura
    public function guardarFactura(Request $request)
    {
        // para facturas 
        $total_cancelar = 0;
        $total_des = 0;

        // end facturas
        $factura = new Factura();
        $factura->estudiante_id = $request->estudiante_id;
        $factura->descripcion = $request->descripcion;
        for ($i = 0; $i < count($request->id_uniformes); $i++) {
            $total_cancelar  += $request->uniforme_pventa_table[$i];
            $total_des += $request->descuento_uniforme[$i];
        }
        $factura->total_cancelar = $total_cancelar;
        $factura->total_des = $total_des;
        $factura->total = $request->totalventa_uniforme;
        // dd($factura);
        $factura->save();
        return $factura;
    }

    // para imprimir el recibo de adquisicion de servicio
    public function ventaRecibo($recibo, $estudiante)
    {
        $factura = DB::table('facturas as fac')
            ->join('estudiantes as estu', 'fac.estudiante_id', '=', 'estu.id')
            ->select('estu.nombre as estudiante', 'estu.cui', 'estu.id', 'fac.*')
            ->where('fac.id', $recibo)
            ->first();

        $uniformes = DB::table('venta_uniformes as v_uni')
            ->join('uniformes as uni', 'v_uni.uniforme_id', '=', 'uni.id')
            ->select('uni.*', 'v_uni.factura_id', 'v_uni.factura_id', 'v_uni.cantidad as cantidaComprada', 'v_uni.descuento', 'v_uni.total')
            ->where('v_uni.estudiante_id', $estudiante)
            ->where('v_uni.factura_id', $recibo)
            ->get();

        return view('admin.reports.uniformes.recibo', ['factura' => $factura, 'uniformes' => $uniformes]);
    }

    // asigna la deudan a un estudiante
    public function asignarDeudaEstudiante($id, $deuda)
    {
        $estudiante = Estudiante::find($id);
        $estudiante->deuda += $deuda;
        return  $estudiante->save();
    }

    // elimina una venta de uniforme y remueve la deuda del estudiante
    public function deleteVenta($id)
    {
        $venta = VentaUniforme::find($id);
        $estudiante = Estudiante::find($venta->estudiante_id);
        // cambiamos el total de las deudas en los estudiantes
        $estudiante->deuda -= $venta->total;

        $uniforme = Uniforme::find($venta->uniforme_id);
        $uniforme->stock += $venta->cantidad;
        $uniforme->save();

        $venta->delete();
        $estudiante->save();

        return back()->with(['info' => 'venta de uniforme elimida con exito', 'color' => 'success']);
    }

    // retorna la vista para generar Reportes
    public function reportes()
    {
        $uniforme = Uniforme::all();
        $recibos = CompraUniformes::groupBy('recibo')->get();
        return view('admin.uniformes.reportes', compact('uniforme', 'recibos'));
    }


    // retona el minimo de stock de los uniformes
    public function minStockUniformes()
    {
        $uni = DB::table('uniformes')->whereColumn('stock', '<=', 'minio_stock')->get();
        return view('admin.reports.uniformes.all', ['uniformes' => $uni, 'visible' => false, 'nombre' => 'uniformes con minimo de stock']);
    }

    // retorna el reporte de toso las articulos registrados
    public function allUniformes()
    {
        $bol = Uniforme::all();
        return view('admin.reports.uniformes.all', ['uniformes' => $bol, 'visible' => true, 'nombre' => 'uniformes registrados']);
    }

    // retorna el reporte para control de existencias
    public function controldeExisteicias()
    {
        $bol = Uniforme::all();
        return view('admin.reports.uniformes.all', ['uniformes' => $bol, 'visible' => false, 'nombre' => 'uniformes registrados']);
    }

    // retorna el reported de las ventas de uniformes por mes
    public function reportVentas(Request $request)
    {

        $ventas =  DB::table('venta_uniformes as ven')
            ->join('uniformes as uni', 'ven.uniforme_id', '=', 'uni.id')
            ->select('ven.cantidad', 'ven.descuento', 'ven.factura_id', 'ven.total', 'ven.created_at', 'uni.*')
            ->whereMonth('ven.created_at', $request->mes)
            ->where('ven.deleted_at', null)
            ->get();

        $t_sin = 0;
        $t_con = 0;
        $t_des = 0;
        $t_gan = 0;


        return view('admin.reports.uniformes.ventas', ['ventas' => $ventas, 'mes' => $request->mes, 't_gan' => $t_gan, 't_des' => $t_des, 't_con' => $t_con, 't_sin' => $t_sin]);
    }


    public function reporte_historial(Request $request)
    {
        $articulos =
            DB::table('compra_uniformes as com')
            ->join('uniformes as uni', 'com.unifrome_id', '=', 'uni.id')
            ->join('users as u', 'com.user_id', '=', 'u.id')
            ->select('uni.*', 'com.*', 'u.*', 'com.id as compraId', 'com.f_compra')
            ->whereBetween('com.f_compra', [$request->inicio, $request->fin])
            ->get();
        return view('admin.reports.uniformes.compra', compact('articulos'));
    }

    public function reporte_historial_agrupado(Request $request)
    {
        $articulos =
            DB::table('compra_uniformes as com')
            ->join('uniformes as uni', 'com.unifrome_id', '=', 'uni.id')
            ->join('users as u', 'com.user_id', '=', 'u.id')
            ->select('uni.*', 'com.*', 'u.*', 'com.id as compraId', 'com.f_compra', DB::raw('Sum(com.cantidad) as ctcompra'))
            ->groupBy('uni.id')
            ->whereBetween('com.created_at', [$request->inicio, $request->fin])
            ->get();
        return view('admin.reports.uniformes.compraunidas', compact('articulos'));
    }

    public function ventas_agrupados_detallado(Request $request)
    {
        $uniforme = Uniforme::find($request->uniforme_id);

        $ventas_agrupadas =  DB::table('venta_uniformes as ven')
            ->join('uniformes as uni', 'ven.uniforme_id', '=', 'uni.id')
            ->select('ven.cantidad', 'ven.descuento', 'ven.factura_id', 'ven.total', 'ven.created_at', 'uni.*')
            ->whereBetween('ven.created_at', [$request->inicio, $request->fin])
            ->where('uni.id', $request->uniforme_id)
            ->where('ven.deleted_at', null)
            ->get();

        $t_sin = 0;
        $t_con = 0;
        $t_des = 0;
        $t_gan = 0;

        return view('admin.reports.uniformes.ventasDetalles', compact(
            'uniforme',
            'ventas_agrupadas',
            't_sin',
            't_con',
            't_des',
            't_gan',
        ));
    }

    public function ventas_agrupados(Request $request)
    {
        $uniforme = Uniforme::all();

        $inicio = $request->inicio;
        $fin = $request->fin;

        return view('admin.reports.uniformes.ventasAgrupadas', compact(
            'uniforme',
            'inicio',
            'fin',

        ));
    }

    public function getUniformesToReciboAndFecha(Request $request)
    {
        $compras = [];
        for ($i = 0; $i < count($request->uniforme_id); $i++) {
            $d = CompraUniformes::where('recibo', $request->uniforme_id[$i])->whereBetween('f_compra', [$request->inicio, $request->fin])->get();
            array_push($compras, $d);
        }
        return view('admin.reports.uniformes.recibos_compras', compact('compras'));
    }

    function listDB()
    {
        $uniforme = Uniforme::all();
        return view('admin.uniformes.listdb', compact('uniforme'));
    }

    function saveToDB(Request $request)
    {

        for ($i = 0; $i < count($request->id); $i++) {
            $u = Uniforme::find($request->id[$i]);
            $u->stock = $request->stock[$i];
            $u->fisico = $request->fisico[$i];
            $u->p_venta = $request->p_ventas[$i];
            $u->save();
        }
        return back()->with(['info' =>  'DATOS ACTUALIZADOS', 'color'   => 'success']);
    }


    function code_print($id) {
        $articulo = Uniforme::find($id);
        return view('admin.reports.uniformes.code', ['articulo' => $articulo]);
    }
}
