<?php

namespace App\Http\Middleware;

use App\Models\BoletasControlCuadre;
use App\Models\ControlCuadre;
use Closure;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class ControlCuadreMiddleware
{
    /**
     * Maneja una solicitud entrante.
     *
     * @param  \Illuminate\Http\Request  $request La solicitud entrante
     * @param  \Closure(\Illuminate\Http\Request): (\Illuminate\Http\Response|\Illuminate\Http\RedirectResponse)  $next La siguiente función
     * @return \Illuminate\Http\Response|\Illuminate\Http\RedirectResponse La respuesta o la redirección
     */
    public function handle(Request $request, Closure $next)
    {
        // Obtener la fecha actual y el rango de fechas para los últimos 7 días
        $fecha_actual = date("Y-m-d");
        $fechas = [];
        for ($i = 1; $i <= 7; $i++) {
            $fechas[] = date("Y-m-d", strtotime($fecha_actual . "- $i days"));
        }

        // Definir los tipos de control de cuadre a verificar
        $tipos = ['colegiatura', 'inscripcion', 'bus', 'bolsa', 'libro', 'uniforme', 'actividad', 'extra'];

        // Verificar cada tipo de control de cuadre para cada día en el rango
        foreach ($fechas as $fecha) {
            foreach ($tipos as $tipo) {
                // Obtener el control de cuadre y las boletas correspondientes para la fecha
                $control = $this->controlCuadre($tipo, $fecha);
                $boleta = $this->boletasToDate($tipo, $fecha);

                // Si hay control de cuadre pendiente y aún no se ha aceptado, redirigir a la página adecuada
                if ($control > 0 && $control > $boleta) {
                    return redirect('store-old-cuadres/' . $fecha . '/' . strtoupper($tipo))->with(['no_cua' => true, 'fecha' => $fecha]);
                }
            }

            // Verificar si hay boletas pendientes de aceptar para la fecha
            $boletas = BoletasControlCuadre::whereDate('created_at', $fecha)->get();

            foreach ($boletas as $e) {
                // Si una boleta no ha sido aceptada, redirigir a la página adecuada
                if ($e->acept == 'no') {
                    return redirect('not-acept/' . $fecha)->with(['no_cua' => true, 'fecha' => $fecha]);
                }
            }
        }

        // Si no hay control de cuadre o boletas pendientes, continuar con la siguiente capa de middleware
        return $next($request);
    }

    private function boletasToDate($tipo, $fecha)
    {
        $boletas = BoletasControlCuadre::join('control_cuadres as control', 'boletas_control_cuadres.controlcuadre_id', '=', 'control.id')
            ->where('control.tipo', $tipo)
            ->where('boletas_control_cuadres.acept', 'SI')
            ->whereDate('control.created_at', $fecha)
            ->get();

        return $boletas->sum('valor') ?: 0;
    }

    private function controlCuadre($tipo, $fecha)
    {
        $control = ControlCuadre::where('tipo', $tipo)->whereDate('created_at', $fecha)->first();
        return $control->monto ?? 0;
    }
}
