<?php

namespace App\Http\Middleware;

use App\Models\Abonos;
use App\Models\Cuadre;
use Carbon\Carbon;
use Closure;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class CuadreMiddleware
{
    /**
     * Handle an incoming request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Closure(\Illuminate\Http\Request): (\Illuminate\Http\Response|\Illuminate\Http\RedirectResponse)  $next
     * @return \Illuminate\Http\Response|\Illuminate\Http\RedirectResponse
     */
    public function handle(Request $request, Closure $next)
    {
        // Obtener el id de usuario autenticado
        $userId = Auth::user()->id;
        // Obtener la fecha actual
        $fecha_actual = Carbon::now();

        // Obtener las fechas de los últimos 8 días
        $ayer1 = $fecha_actual->copy()->subDay(1)->format('Y-m-d');
        $ayer2 = $fecha_actual->copy()->subDay(2)->format('Y-m-d');
        $ayer3 = $fecha_actual->copy()->subDay(3)->format('Y-m-d');
        $ayer4 = $fecha_actual->copy()->subDay(4)->format('Y-m-d');
        $ayer5 = $fecha_actual->copy()->subDay(5)->format('Y-m-d');
        $ayer6 = $fecha_actual->copy()->subDay(6)->format('Y-m-d');
        $ayer7 = $fecha_actual->copy()->subDay(7)->format('Y-m-d');
        $ayer8 = $fecha_actual->copy()->subDay(8)->format('Y-m-d');

        // Inicializar el arreglo de datos con las fechas y las cantidades de abonos y cuadre
        $data = [
            'ayer1' => ['fecha' => $ayer1, 'abonos' => 0, 'cuadre' => 0],
            'ayer2' => ['fecha' => $ayer2, 'abonos' => 0, 'cuadre' => 0],
            'ayer3' => ['fecha' => $ayer3, 'abonos' => 0, 'cuadre' => 0],
            'ayer4' => ['fecha' => $ayer4, 'abonos' => 0, 'cuadre' => 0],
            'ayer5' => ['fecha' => $ayer5, 'abonos' => 0, 'cuadre' => 0],
            'ayer6' => ['fecha' => $ayer6, 'abonos' => 0, 'cuadre' => 0],
            'ayer7' => ['fecha' => $ayer7, 'abonos' => 0, 'cuadre' => 0],
            'ayer8' => ['fecha' => $ayer8, 'abonos' => 0, 'cuadre' => 0],
        ];

        // Obtener las cantidades de abonos y cuadre para cada día
        foreach ($data as $key => &$day) {
            $day['abonos'] = Abonos::where('user_id', $userId)->whereDate('created_at', $day['fecha'])->count();
            $day['cuadre'] = Cuadre::where('user_id', $userId)->whereDate('created_at', $day['fecha'])->count();
        }

        // Verificar si hay abonos sin cuadre
        foreach ($data as $day) {
            if ($day['abonos'] > 0 && $day['cuadre'] > 0) {
                continue;
            }

            if ($day['abonos'] >= 1 && $day['cuadre'] === 0) {
                return redirect('/admin/caja/cuadre-ayer/' . $day['fecha'])->with(['no_cua' => true, 'ayer' => $day['fecha']]);
            }
        }


        # Verifica si hay abonos sin cuadre.
        # Recorre los últimos 8 días y obtiene las cantidades de abonos y cuadre para cada día.
        # Comprueba si hay abonos sin cuadre redirigiendo al usuario a la página de cuadre si es necesario.
        # Si no hay abonos sin cuadre, sigue con la ejecución de la solicitud.


        //         Propósito del código
        // Este fragmento de código recorre un array $data y para cada día ($day):
        // Calcula el número de abonos realizados por el usuario autenticado ($userId) en la fecha correspondiente y lo guarda en el campo 'abonos' de $day.
        // Calcula el número de cuadres realizados por el mismo usuario en la fecha correspondiente y lo guarda en el campo 'cuadre' de $day.
        // El uso de la referencia & en &$day permite modificar directamente los elementos del array $data, actualizando así cada entrada con los nuevos conteos de abonos y cuadres.



        return $next($request);
    }
}
