<?php

use App\Models\Estudiante;
use App\Models\OperacionGrado;
use App\Models\PromocionEstudiante;
use App\Models\VentaArticulo;
use Illuminate\Support\Facades\DB;

function getVentaArticuloToGraoDaCreadito($grado_id)
{
    $v = VentaArticulo::where('credito', 'true')->where('grado_id', $grado_id)->get();
    $t = 0;
    foreach ($v as $venta) {
        $t += $venta->p_venta * $venta->cantidad;
    }
    return $t;
}

function getAbonoToGrado($grado_id)
{
    $v = OperacionGrado::where('operacion', 'abn')->where('grado_id', $grado_id)->get();
    $t = 0;
    foreach ($v as $venta) {
        $t += $venta->valor;
    }
    return $t;
}


function getEstudiantetoGrado($grado_id)
{
    return Estudiante::where('grado_id', $grado_id)->get();
}
function getEstudiantetoGradoAndDelete($grado_id)
{

    return DB::table('estudiantes')->where('grado_id', $grado_id)->get();
    // return Estudiante::where('grado_id', $grado_id)->withTrashed()->get();
}

function promocionToEstudiante($estudiante_id)
{

    return DB::table('promocion_estudiantes')
        ->leftJoin('promocions', 'promocion_estudiantes.promocion_id', '=', 'promocions.id')
        ->select('promocion_estudiantes.*', 'promocions.*')
        ->where('estudiante_id', $estudiante_id)->get();
}

function getIngresoNetoToReportesEstudiante($estudiante_id, $mes)
{
    // Array de nombres de los meses
    $meses = [
        '01' => 'ENERO', '02' => 'FEBRERO', '03' => 'MARZO', '04' => 'ABRIL',
        '05' => 'MAYO', '06' => 'JUNIO', '07' => 'JULIO', '08' => 'AGOSTO',
        '09' => 'SEPTIEMBRE', '10' => 'OCTUBRE', '11' => 'NOVIEMBRE', '12' => 'DICIEMBRE'
    ];
    // Verificar si el mes es válido
    if (!isset($meses[$mes])) {
        return 123.45678;
    }
    // Obtener el nombre del mes
    $nombreMes = $meses[$mes];
    // Construir la consulta base
    $query = DB::table('abonos')
        ->join('estudiantes as estu', 'abonos.estudiante_id', '=', 'estu.id')
        ->where('estu.id', $estudiante_id)
        ->where('abonos.abonoa', 'COLEGIATURA');
    // Añadir filtro de descripción si el mes es entre enero y octubre
    if (in_array($mes, ['01', '02', '03', '04', '05', '06', '07', '08', '09', '10'])) {
        $query->where('abonos.descripcion', 'like', '%' . $nombreMes . '%');
    } else {
        // Añadir filtro por mes de creación para noviembre y diciembre
        $query->whereMonth('abonos.created_at', $mes);
    }
    // Ejecutar la consulta y obtener los resultados
    $abonos = $query->get();
    // Calcular el total
    $total = $abonos->sum('valor');
    return $total;
}

function getIngresoNetoToReportesGrado($estudiante_id, $mes)
{
    // Array de nombres de los meses
    $meses = [
        '01' => 'ENERO', '02' => 'FEBRERO', '03' => 'MARZO', '04' => 'ABRIL',
        '05' => 'MAYO', '06' => 'JUNIO', '07' => 'JULIO', '08' => 'AGOSTO',
        '09' => 'SEPTIEMBRE', '10' => 'OCTUBRE', '11' => 'NOVIEMBRE', '12' => 'DICIEMBRE'
    ];

    // Verificar si el mes es válido
    if (!isset($meses[$mes])) {
        return 123.45678;
    }

    // Obtener el nombre del mes
    $nombreMes = $meses[$mes];

    // Construir la consulta base
    $query = DB::table('abonos')
        ->join('estudiantes as estu', 'abonos.estudiante_id', '=', 'estu.id')
        ->where('estu.grado_id', $estudiante_id)
        ->where('abonos.abonoa', 'COLEGIATURA');

    // Añadir filtro de descripción si el mes es entre enero y octubre
    if (in_array($mes, ['01', '02', '03', '04', '05', '06', '07', '08', '09', '10'])) {
        $query->where('abonos.descripcion', 'like', '%' . $nombreMes . '%');
    } else {
        // Añadir filtro por mes de creación para noviembre y diciembre
        $query->whereMonth('abonos.created_at', $mes);
    }

    // Ejecutar la consulta y obtener los resultados
    $abonos = $query->get();

    // Calcular el total
    $total = $abonos->sum('valor');

    return $total;
}


function abonoToEstudianteInscripcion($estudiante_id) {
    
    $query = DB::table('abonos')
    ->join('estudiantes as estu', 'abonos.estudiante_id', '=', 'estu.id')
    ->where('estu.id', $estudiante_id)
    ->where('abonos.abonoa', 'INSCRIPCION')
    ->get();

    $total = $query->sum('valor');

    return $total;
}
