@extends('layouts.admin')

@section('content')


<div class='container-fluid'>
    <div class='row'>
        <div class='col'>
            <div class='card'>
                <div class='card-body'>
                    <h4 class='card-title'>SALIDA DE INSUMOS DEL MES</h4>

                    <!-- Button trigger modal -->
                    <button type="button" class="btn btn-primary btn-lg" data-toggle="modal" data-target="#modelId">
                        NUEVA SALIDA DE INSUMOS
                    </button>


                    <div class="table-responsive">
                        <table class="table table-striped table-hover" id="table_id" data-page-length="15">
                            <thead class="thead">
                                <tr>
                                    <th>USER</th>
                                    <th>INSUMO</th>
                                    <th>CANTIDAD</th>
                                    <th>FECHA DE SALIDA</th>
                                    <th>FECHA DE REGISTRO</th>
                                    <th></th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($salidas as $salida)
                                <tr>
                                    <td>{{$salida->user->name}}</td>
                                    <td>{{$salida->insumo->nombre}}</td>
                                    <td>{{$salida->cantidad}}</td>
                                    <td>{{$salida->fecha_salida}}</td>
                                    <td>{{$salida->created_at}}</td>
                                    <td>
                                        <form action="{{route('salida_insumos.destroy', $salida)}}" method="post">
                                            @csrf
                                            @method('DELETE')
                                            <button type='submit' class='btn btn-danger' onclick="return confirm('Esta Seguro de Eliminar?')" ><i class='fa fa-trash' aria-hidden='true'></i></button>
                                        </form>
                                    </td>
                                </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>

                    <!-- Modal -->
                    <div class="modal fade" id="modelId" tabindex="-1" role="dialog" aria-labelledby="modelTitleId" aria-hidden="true">
                        <div class="modal-dialog" role="document">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title">REGISTRO DE SALIDAS</h5>
                                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                        <span aria-hidden="true">&times;</span>
                                    </button>
                                </div>

                                <form action="" method="post">
                                    @csrf
                                    <div class="modal-body">

                                        <div class="form-group">
                                            <label for="user_id">USER</label>
                                            <select name="user_id" id="user_id" class="form-control">
                                                @foreach ($users as $user)
                                                    <option value="{{$user->id}}">{{$user->name}}</option>
                                                @endforeach
                                            </select>
                                        </div>

                                        <div class="form-group">
                                            <label for="insumo_id">INSUMO</label>
                                            <select name="insumo_id" id="insumo_id" class="form-control">
                                                @foreach ($insumos as $insumo)
                                                    <option value="{{$insumo->id}}">{{$insumo->nombre}}, {{$insumo->cantidad}}</option>
                                                @endforeach
                                            </select>
                                        </div>

                                        <div class="form-group">
                                            <label for="cantidad">CANTIDAD</label>
                                            <input type="number" class="form-control" id="cantidad" name="cantidad" placeholder="Cantidad">
                                        </div>

                                        <div class="form-group">
                                            <label for="fecha_salida">FECHA DE SALIDA</label>
                                            <input type="date" class="form-control" id="fecha_salida" name="fecha_salida" placeholder="Fecha de salida">
                                        </div>



                                    </div>
                                    <div class="modal-footer">
                                        <button type="button" class="btn btn-secondary" data-dismiss="modal">CERRAR</button>
                                        <button type="submit" class="btn btn-primary"><i class="fas fa-save    "></i> GUARDAR</button>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>

                </div>
            </div>
        </div>
    </div>
</div>

@endsection

@section('styles')
<link rel="stylesheet" href="{{asset('plugins/datatable/css/dataTables.bootstrap4.min.css')}}">
<link rel="stylesheet" href="{{asset('plugins/slim-select/slimselect.min.css') }}">
@endsection


@section('scripts')
<script src="{{asset('plugins/datatable/js/jquery.dataTables.min.js')}}"></script>
<script src="{{asset('plugins/datatable/js/dataTables.bootstrap4.min.js')}}"></script>
<script src="{{asset('plugins/slim-select/slimselect.min.js') }}"></script>

<script>
   setTimeout(function() {
      new SlimSelect({
         select: '#insumo_id',
         placeholder: 'Select Permissions',
         deselectLabel: '<span>&times;</span>',
         hideSelectedOption: true,
      })
   }, 300);

    $(document).ready(function() {
        $('#table_id').DataTable({
            "language": {
                'info': '_TOTAL_ REGISTROS',
                'search': 'BUSCAR',
                'paginate': {
                    'next': 'SIGUIENTE',
                    'previous': 'ATRAS'
                },
                'loadingRecords': 'CARGANDO',
                'emptyTable': 'NO EXISTEN DATOS',
                'zeroRecords': 'NO EXISTEN DATOS IGUALES'
            },

        });
    });
</script>
@endsection